@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -32,8 +32,6 @@
 
 #include "EventHandler.h"
 
-#define FILE_METHODS 1
-
 namespace libdap
 {
 
@@ -47,40 +45,27 @@ namespace libdap
 class AlarmHandler : public EventHandler
 {
 private:
-#if FILE_METHODS
     FILE *d_file;  // Sink for the Error object.
-#endif
     ostream &d_stream;
     string d_version;
 
     // Ensure that d_stream gets initialized...
-    AlarmHandler() :
-#if FILE_METHODS
-        d_file( 0 ),
-#endif
-        d_stream( cout )
+    AlarmHandler() : d_file( 0 ), d_stream( cout )
     {}
 
 public:
-#if FILE_METHODS
     AlarmHandler(FILE *s) : d_file(s), d_stream( cout )
     {}
-#endif
+
     /** Store information to be used by the handler.
     @param out Write to this stream. */
-    AlarmHandler(ostream &out) :
-#if FILE_METHODS
-        d_file(0),
-#endif
-        d_stream( out )
+    AlarmHandler(ostream &out) : d_file(0), d_stream( out )
     {}
 
     virtual ~AlarmHandler()
     {
-#if FILE_METHODS
         if( d_file )
             fclose( d_file ) ;
-#endif
     }
 
     /** Handle an alarm signal. When one of our servers gets an alarm, that
@@ -89,8 +74,7 @@ public:
     has been reached.
 
     Because this is a signal handler, it should call only reentrant
-    system services, functions, et cetera. Generally that eliminates
-    stdio functions but I'm using them anyway. This handler never returns
+    system services, functions, et cetera. This handler never returns
     to the code that was running when the alarm signal was raised.
 
     @param signum We know it is SIGALRM; here as a check
@@ -98,8 +82,9 @@ public:
     virtual void handle_signal(int signum)
     {
         if (signum != SIGALRM)
-            fprintf(stderr, "SIGALRM handler caught another signal!\n");
-        exit(1);
+            throw Error("SIGALRM handler caught another signal!");
+
+        throw Error("Timeout");
     }
 
 };
