@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -48,7 +48,9 @@
 #include "Vector.h"
 #endif
 
-#define FILE_METHODS 1
+#ifndef XMLWRITER_H_
+#include "XMLWriter.h"
+#endif
 
 namespace libdap
 {
@@ -129,10 +131,9 @@ private:
 protected:
     void _duplicate(const Array &a);
 
-#if FILE_METHODS
     unsigned int print_array(FILE *out, unsigned int index,
                              unsigned int dims, unsigned int shape[]);
-#endif
+
     unsigned int print_array(ostream &out, unsigned int index,
                              unsigned int dims, unsigned int shape[]);
 
@@ -160,9 +161,11 @@ public:
     virtual BaseType *ptr_duplicate();
 
     void add_var(BaseType *v, Part p = nil);
+    void add_var_nocopy(BaseType *v, Part p = nil);
 
     void append_dim(int size, string name = "");
     void prepend_dim(int size, const string& name = "");
+    void clear_all_dims();
 
     virtual void add_constraint(Dim_iter i, int start, int stride, int stop);
     virtual void reset_constraint();
@@ -170,6 +173,7 @@ public:
     virtual void clear_constraint();
 
     virtual void update_length(int size);
+    virtual unsigned int width(bool constrained = false);
 
     Dim_iter dim_begin() ;
     Dim_iter dim_end() ;
@@ -190,9 +194,11 @@ public:
     virtual void print_xml(ostream &out, string space = "    ",
                            bool constrained = false);
 
-#if FILE_METHODS
+    virtual void print_xml_writer(XMLWriter &xml, bool constrained = false);
+    virtual void print_xml_writer_core(XMLWriter &out, bool constrained, string tag);
+    virtual void print_as_map_xml_writer(XMLWriter &xml, bool constrained);
+
     virtual void print_xml_core(FILE *out, string space, bool constrained, string tag);
-#endif
     virtual void print_xml_core(ostream &out, string space, bool constrained, string tag);
 
     // not used (?)
@@ -202,7 +208,6 @@ public:
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
-#if FILE_METHODS
     virtual void print_xml(FILE *out, string space = "    ",
                            bool constrained = false);
     virtual void print_as_map_xml(FILE *out, string space = "    ",
@@ -213,7 +218,6 @@ public:
                             bool print_semi = true,
                             bool constraint_info = false,
                             bool constrained = false);
-#endif
 
     virtual bool check_semantics(string &msg, bool all = false);
 
