@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -50,6 +50,10 @@ using std::vector;
 #include "DapObj.h"
 #endif
 
+#ifndef XMLWRITER_H_
+#include "XMLWriter.h"
+#endif
+
 namespace libdap
 {
 
@@ -338,6 +342,8 @@ public:
     virtual void print_xml(ostream &out, string pad = "    ",
 			   bool constrained = false);
 
+    void print_xml_writer(XMLWriter &xml);
+
     virtual void dump(ostream &strm) const ;
 };
 
