@@ -18,7 +18,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -42,10 +42,13 @@
 namespace libdap
 {
 
+class ServerFunctionsList;
+
 /** @brief Evaluate a constraint expression */
 class ConstraintEvaluator
 {
 private:
+#if 0
     // This struct is used to hold all the known `user defined' functions
     // (including those that are `built-in').
     struct function
@@ -67,12 +70,15 @@ private:
         function(): name(""), bt_func(0), p_func(0)
         {}
     };
-
+#endif
     vector<Clause *> expr;      // List of CE Clauses
 
     vector<BaseType *> constants;// List of temporary objects
-
+#if 0
     list<function> functions; // Known external functions
+#endif
+    ServerFunctionsList *d_functions_list;  // Know external functions from
+                                            // modules
 
     // The default versions of these methods will break this class. Because
     // Clause does not support deep copies, that class will need to be modified
@@ -92,17 +98,19 @@ public:
 
     typedef std::vector<BaseType *>::const_iterator Constants_citer ;
     typedef std::vector<BaseType *>::iterator Constants_iter ;
-
+#if 0
     typedef std::list<function>::const_iterator Functions_citer ;
     typedef std::list<function>::iterator Functions_iter ;
+#endif
 
     ConstraintEvaluator();
-    virtual ~ConstraintEvaluator();
 
+    virtual ~ConstraintEvaluator();
+#if 0
     void add_function(const string &name, bool_func f);
     void add_function(const string &name, btp_func f);
     void add_function(const string &name, proj_func f);
-
+#endif
     bool find_function(const string &name, bool_func *f) const;
     bool find_function(const string &name, btp_func *f) const;
     bool find_function(const string &name, proj_func *f) const;
