@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -36,11 +36,6 @@
 
 #include "config.h"
 
-static char rcsid[] not_used =
-    {"$Id: DAS.cc 24281 2011-03-09 00:22:31Z jimg $"
-    };
-
-
 #include <cstdio>
 
 #ifdef HAVE_UNISTD_H
@@ -70,8 +65,9 @@ extern void das_switch_to_buffer(void *new_buffer);
 extern void das_delete_buffer(void * buffer);
 extern void *das_buffer(FILE *fp);
 
-extern void dasrestart(FILE *yyin);
-extern int dasparse(void *arg); // defined in das.tab.c
+//extern void dasrestart(FILE *yyin);
+//extern int dasparse(void *arg); // defined in das.tab.c
+extern int dasparse(libdap::parser_arg *arg); // defined in das.tab.c
 
 namespace libdap {
 
@@ -109,24 +105,20 @@ DAS::container_name()
  *
  * @param cn container name
  */
-void
-DAS::container_name( const string &cn )
+void DAS::container_name(const string &cn)
 {
     // We want to find a top level attribute table with the given name. So
     // set d_container to null first so that we aren't searching some
     // previous container
-    if( cn != _container_name )
-    {
-	d_container = 0 ;
-	if( !cn.empty() )
-	{
-	    d_container = get_table( cn ) ;
-	    if( !d_container )
-	    {
-		d_container = add_table( cn, new AttrTable ) ;
-	    }
-	}
-	_container_name = cn;
+    if (cn != _container_name) {
+        d_container = 0;
+        if (!cn.empty()) {
+            d_container = get_table(cn);
+            if (!d_container) {
+                d_container = add_table(cn, new AttrTable);
+            }
+        }
+        _container_name = cn;
     }
 }
 
@@ -147,66 +139,55 @@ DAS::container()
  * attribute tables for the current container. If not set then return the
  * number of current attribute tables in the outermost attribute table.
  */
-unsigned int
-DAS::get_size() const
+unsigned int DAS::get_size() const
 {
-    if( d_container )
-    {
-	return d_container->get_size() ;
+    if (d_container) {
+        return d_container->get_size();
     }
-    return d_attrs.get_size() ;
+    return d_attrs.get_size();
 }
 
 /** @brief erase all attributes in this DAS
  */
-void
-DAS::erase()
+void DAS::erase()
 {
-    if( d_container )
-    {
-	d_container->erase() ;
+    if (d_container) {
+        d_container->erase();
     }
-    else
-    {
-	d_attrs.erase() ;
+    else {
+        d_attrs.erase();
     }
 }
 
 /** @brief Returns a reference to the attribute table for the first variable.
  */
-AttrTable::Attr_iter
-DAS::var_begin()
+AttrTable::Attr_iter DAS::var_begin()
 {
-    if( d_container )
-    {
-	return d_container->attr_begin() ;
+    if (d_container) {
+        return d_container->attr_begin();
     }
-    return d_attrs.attr_begin() ;
+    return d_attrs.attr_begin();
 }
 
 /** Returns a reference to the end of the attribute table. Does not
  *  point to an attribute table.
  */
-AttrTable::Attr_iter
-DAS::var_end()
+AttrTable::Attr_iter DAS::var_end()
 {
-    if( d_container )
-    {
-	return d_container->attr_end() ;
+    if (d_container) {
+        return d_container->attr_end();
     }
-    return d_attrs.attr_end() ;
+    return d_attrs.attr_end();
 }
 
 /** @brief Returns the name of the referenced variable attribute table.
  */
-string
-DAS::get_name(AttrTable::Attr_iter &i)
+string DAS::get_name(AttrTable::Attr_iter &i)
 {
-    if( d_container )
-    {
-	return d_container->get_name( i ) ;
+    if (d_container) {
+        return d_container->get_name(i);
     }
-    return d_attrs.get_name( i ) ;
+    return d_attrs.get_name(i);
 }
 
 /** @brief Returns the referenced variable attribute table.
@@ -214,23 +195,21 @@ DAS::get_name(AttrTable::Attr_iter &i)
 AttrTable *
 DAS::get_table(AttrTable::Attr_iter &i)
 {
-    if( d_container )
-    {
-	return d_container->get_attr_table( i ) ;
+    if (d_container) {
+        return d_container->get_attr_table(i);
     }
-    return d_attrs.get_attr_table( i ) ;
+    return d_attrs.get_attr_table(i);
 }
 
 /** @brief Returns the variable attribute table with the given name.
  */
 AttrTable *
-DAS::get_table( const string &name )
+DAS::get_table(const string &name)
 {
-    if( d_container )
-    {
-	return d_container->get_attr_table( name ) ;
+    if (d_container) {
+        return d_container->get_attr_table(name);
     }
-    return d_attrs.get_attr_table( name ) ;
+    return d_attrs.get_attr_table(name);
 }
 
 //@}
@@ -246,10 +225,9 @@ DAS::get_table( const string &name )
 AttrTable *
 DAS::add_table( const string &name, AttrTable *at )
 {
-    if( d_container )
-    {
-	at->set_is_global_attribute( false ) ;
-	return d_container->append_container( at, name ) ;
+    if (d_container) {
+        at->set_is_global_attribute(false);
+        return d_container->append_container(at, name);
     }
     return d_attrs.append_container( at, name ) ;
 }
@@ -335,7 +313,8 @@ DAS::parse(FILE *in)
 
     parser_arg arg(this);
 
-    bool status = dasparse((void *) & arg) == 0;
+    //bool status = dasparse((void *) & arg) == 0;
+    bool status = dasparse(&arg) == 0;
 
     das_delete_buffer(buffer);
 
