@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -42,8 +42,6 @@
 #include <string>
 #include <iostream>
 
-//#include "Pix.h"
-
 #ifndef _attrtable_h
 #include "AttrTable.h"
 #endif
@@ -127,12 +125,8 @@ private:
     string _container_name ;
     AttrTable d_attrs ;
 
-protected:
-    //AttrTable *das_find(string name);
-
 public:
     DAS();
-    //DAS(AttrTable *attr_table, string name);
 
     virtual ~DAS();
 
@@ -146,11 +140,11 @@ public:
      * the top most dataset container attribute tables, if we have multiple
      * datasets being used to construct this DAS
      */
-    virtual AttrTable *get_top_level_attributes()
-    {
-	if( d_container ) return d_container ;
-	return &d_attrs ;
-    }
+    virtual AttrTable *get_top_level_attributes() {
+		if (d_container)
+			return d_container;
+		return &d_attrs;
+	}
 
     virtual void erase() ;
 
