@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -54,7 +54,8 @@
 
 namespace libdap {
 
-static const not_used char *states[] =
+#if defined(DODS_DEBUG) || defined(DODS_DEUG2)
+static const char *states[] =
     {
         "start",
 
@@ -83,7 +84,7 @@ static const not_used char *states[] =
         "unknown",
         "error"
     };
-
+#endif
 // Glue the BaseTypeFactory to the enum-based factory defined statically
 // here.
 
@@ -147,6 +148,7 @@ BaseType *DDXParser::factory(Type t, const string & name)
     }
 }
 
+#if 0
 /** Get the Type enumeration value which matches the given name. */
 static Type get_type(const char *name)
 {
@@ -191,7 +193,10 @@ static Type get_type(const char *name)
 
     return dods_null_c;
 }
+#endif
 
+#if 0
+// Not used. jhrg 1/17/13
 static Type is_simple_type(const char *name)
 {
     Type t = get_type(name);
@@ -210,6 +215,7 @@ static Type is_simple_type(const char *name)
         return dods_null_c;
     }
 }
+#endif
 
 static bool is_not(const char *name, const char *tag)
 {
@@ -437,8 +443,9 @@ DDXParser::is_attribute_or_alias(const char *name, const xmlChar **attrs,
 inline bool DDXParser::is_variable(const char *name, const xmlChar **attrs,
         int nb_attributes)
 {
-    Type t;
-    if ((t = is_simple_type(name)) != dods_null_c) {
+    Type t = get_type(name);
+    //if ((t = is_simple_type(name)) != dods_null_c) {
+    if (is_simple_type(t)) {
         process_variable(t, inside_simple_type, attrs, nb_attributes);
         return true;
     }
@@ -486,10 +493,11 @@ void DDXParser::finish_variable(const char *tag, Type t, const char *expected)
     }
     // Once libxml2 validates, this can go away. 05/30/03 jhrg
     if (t == dods_array_c
-        && dynamic_cast < Array * >(btp)->dimensions() == 0) {
+        && static_cast<Array*>(btp)->dimensions() == 0) {
         DDXParser::ddx_fatal_error(this,
                                    "No dimension element included in the Array '%s'.",
                                    btp->name().c_str());
+        delete btp;
         return;
     }
 
@@ -501,10 +509,12 @@ void DDXParser::finish_variable(const char *tag, Type t, const char *expected)
                                    tag,
                                    bt_stack.top()->type_name().c_str(),
                                    bt_stack.top()->name().c_str());
+        delete btp;
         return;
     }
 
     parent->add_var(btp);
+    delete btp;
 }
 
 /** @name SAX Parser Callbacks
@@ -546,25 +556,28 @@ void DDXParser::ddx_end_document(void * p)
          endl);
 
     if (parser->get_state() != parser_start)
-        DDXParser::ddx_fatal_error(parser,
-                                   "The document contained unbalanced tags.");
+        DDXParser::ddx_fatal_error(parser, "The document contained unbalanced tags.");
 
     // If we've found any sort of error, don't make the DDX; intern() will
     // take care of the error.
-    if (parser->get_state() == parser_error)
+    if (parser->get_state() == parser_error) {
+    	delete parser->bt_stack.top();
         return;
+    }
 
     // Pop the temporary Structure off the stack and transfer its variables
     // to the DDS.
     Constructor *cp = dynamic_cast < Constructor * >(parser->bt_stack.top());
     if (!cp) {
     	ddx_fatal_error(parser, "Parse error: Expected a Structure, Sequence or Grid variable.");
+    	delete cp;
 		return;
     }
-    
-    for (Constructor::Vars_iter i = cp->var_begin(); i != cp->var_end();
-         ++i)
+
+    for (Constructor::Vars_iter i = cp->var_begin(); i != cp->var_end(); ++i) {
+        (*i)->set_parent(0);        // top-level vars have no parents
         parser->dds->add_var(*i);
+    }
 
     parser->bt_stack.pop();
     delete cp;
@@ -898,8 +911,9 @@ void DDXParser::ddx_sax2_end_element(void *p, const xmlChar *l,
         parser->pop_state();
         break;
 
-    case inside_simple_type:
-        if (is_simple_type(localname) != dods_null_c) {
+    case inside_simple_type: {
+        Type t = get_type(localname);
+        if (is_simple_type(t)) {
             parser->pop_state();
             BaseType *btp = parser->bt_stack.top();
             parser->bt_stack.pop();
@@ -907,8 +921,10 @@ void DDXParser::ddx_sax2_end_element(void *p, const xmlChar *l,
 
             BaseType *parent = parser->bt_stack.top();
 
-            if (parent->is_vector_type() || parent->is_constructor_type())
+            if (parent->is_vector_type() || parent->is_constructor_type()) {
                 parent->add_var(btp);
+                delete btp;
+            }
             else
                 DDXParser::ddx_fatal_error(parser,
                                            "Tried to add the simple-type variable '%s' to a non-constructor type (%s %s).",
@@ -923,6 +939,7 @@ void DDXParser::ddx_sax2_end_element(void *p, const xmlChar *l,
                                        "Expected an end tag for a simple type; found '%s' instead.",
                                        localname);
         break;
+    }
 
     case inside_array:
         parser->finish_variable(localname, dods_array_c, "Array");
@@ -1106,13 +1123,82 @@ void DDXParser::cleanup_parse(xmlParserCtxtPtr & context) const
     xmlFreeParserCtxt(context);
 }
 
-/** @brief Read the DDX from a stream instead of a file.
-    @see DDXParser::intern(). */
-void DDXParser::intern_stream(FILE *in, DDS *dest_dds, string &cid,
-	const string &boundary)
+/** Read a DDX from a C++ input stream and populate a DDS object.
+ *
+ * @param in
+ * @param dds
+ * @param cid
+ * @param boundary
+ */
+void DDXParser::intern_stream(istream &in, DDS *dest_dds, string &cid, const string &boundary)
 {
     // Code example from libxml2 docs re: read from a stream.
+    if (!in || in.eof())
+        throw InternalErr(__FILE__, __LINE__, "Input stream not open or read error");
 
+    const int size = 1024;
+    char chars[size + 1];
+
+    // int res = fread(chars, 1, 4, in);
+    in.readsome(chars, 4);
+    int res = in.gcount();
+    if (res > 0) {
+        chars[4]='\0';
+        xmlParserCtxtPtr context = xmlCreatePushParserCtxt(NULL, NULL, chars, res, "stream");
+
+        ctxt = context;         // need ctxt for error messages
+        dds = dest_dds;         // dump values here
+        blob_href = &cid; 	// cid goes here
+
+        xmlSAXHandler ddx_sax_parser;
+        memset( &ddx_sax_parser, 0, sizeof(xmlSAXHandler) );
+
+        ddx_sax_parser.getEntity = &DDXParser::ddx_get_entity;
+        ddx_sax_parser.startDocument = &DDXParser::ddx_start_document;
+        ddx_sax_parser.endDocument = &DDXParser::ddx_end_document;
+        ddx_sax_parser.characters = &DDXParser::ddx_get_characters;
+        ddx_sax_parser.ignorableWhitespace = &DDXParser::ddx_ignoreable_whitespace;
+        ddx_sax_parser.cdataBlock = &DDXParser::ddx_get_cdata;
+        ddx_sax_parser.warning = &DDXParser::ddx_fatal_error;
+        ddx_sax_parser.error = &DDXParser::ddx_fatal_error;
+        ddx_sax_parser.fatalError = &DDXParser::ddx_fatal_error;
+        ddx_sax_parser.initialized = XML_SAX2_MAGIC;
+        ddx_sax_parser.startElementNs = &DDXParser::ddx_sax2_start_element;
+        ddx_sax_parser.endElementNs = &DDXParser::ddx_sax2_end_element;
+
+        context->sax = &ddx_sax_parser;
+        context->userData = this;
+        context->validate = true;
+
+        in.getline(chars, size);	// chars has size+1 elements
+        res = in.gcount();
+        chars[res-1] = '\n';		// libxml needs the newline; w/o it the parse will fail
+        chars[res] = '\0';
+        while (res > 0 && !is_boundary(chars, boundary)) {
+        	DBG(cerr << "line (" << res << "): " << chars << endl);
+        	xmlParseChunk(ctxt, chars, res, 0);
+
+        	in.getline(chars, size);	// chars has size+1 elements
+        	res = in.gcount();
+        	if (res > 0) {
+        		chars[res-1] = '\n';
+        		chars[res] = '\0';
+        	}
+        }
+
+        // This call ends the parse: The fourth argument of xmlParseChunk is
+        // the bool 'terminate.'
+        xmlParseChunk(ctxt, chars, 0, 1);
+
+        cleanup_parse(context);
+    }
+}
+
+/** @brief Read the DDX from a stream instead of a file.
+    @see DDXParser::intern(). */
+void DDXParser::intern_stream(FILE *in, DDS *dest_dds, string &cid, const string &boundary)
+{
+    // Code example from libxml2 docs re: read from a stream.
     if (!in || feof(in) || ferror(in))
         throw InternalErr(__FILE__, __LINE__,
                           "Input stream not open or read error");
@@ -1122,6 +1208,7 @@ void DDXParser::intern_stream(FILE *in, DDS *dest_dds, string &cid,
 
     int res = fread(chars, 1, 4, in);
     if (res > 0) {
+        chars[4]='\0';
         xmlParserCtxtPtr context =
             xmlCreatePushParserCtxt(NULL, NULL, chars, res, "stream");
 
@@ -1151,8 +1238,9 @@ void DDXParser::intern_stream(FILE *in, DDS *dest_dds, string &cid,
 
 
         while ((fgets(chars, size, in) > 0) && !is_boundary(chars, boundary)) {
-            chars[size-1] = '\0';
-            DBG(cerr << "line: " << chars << endl);
+            //chars[size-1] = '\0';
+            DBG(cerr << "line (" << strlen(chars) << "): " << chars << endl);
+
             xmlParseChunk(ctxt, chars, strlen(chars), 0);
         }
         // This call ends the parse: The fourth argument of xmlParseChunk is
