@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -240,8 +240,8 @@ public:
     {}
 
     void intern(const string &document, DDS *dest_dds, string &cid);
-    void intern_stream(FILE *in, DDS *dds, string &cid,
-		const string &boundary = "");
+    void intern_stream(FILE *in, DDS *dds, string &cid, const string &boundary = "");
+    void intern_stream(istream &in, DDS *dds, string &cid, const string &boundary = "");
 
     static void ddx_start_document(void *parser);
     static void ddx_end_document(void *parser);
