@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -35,7 +35,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: Error.cc 18940 2008-06-25 19:22:37Z jimg $"
+    {"$Id: Error.cc 27197 2013-10-01 21:29:54Z jimg $"
     };
 
 #include <cstdio>
@@ -53,8 +53,8 @@ extern void Error_switch_to_buffer(void *new_buffer);
 extern void Error_delete_buffer(void * buffer);
 extern void *Error_buffer(FILE *fp);
 
-extern void Errorrestart(FILE *yyin); // defined in Error.tab.c
-extern int Errorparse(void *arg);
+//extern void Errorrestart(FILE *yyin); // defined in Error.tab.c
+extern int Errorparse(libdap::parser_arg *arg);
 
 namespace libdap {
 
@@ -168,7 +168,7 @@ Error::parse(FILE *fp)
 
     bool status;
     try {
-        status = Errorparse((void *) & arg) == 0;
+        status = Errorparse(&arg) == 0;
         Error_delete_buffer(buffer);
     }
     catch (Error &e) {
