@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -33,28 +33,26 @@
 //
 // 3/22/99 jhrg
 
-
-#include <iomanip>
-
 #include "config.h"
 
-static char rcsid[] not_used =
-    {"$Id: Float32.cc 21699 2009-11-05 00:06:01Z jimg $"
-    };
+#include <sstream>
+#include <iomanip>
 
-#include "Byte.h"
+#include "Byte.h"           // synonymous with UInt8 and Char
+#include "Int8.h"
 #include "Int16.h"
 #include "UInt16.h"
 #include "Int32.h"
 #include "UInt32.h"
+#include "Int64.h"
+#include "UInt64.h"
 #include "Float32.h"
 #include "Float64.h"
 #include "Str.h"
 #include "Url.h"
-#include "Array.h"
-#include "Structure.h"
-#include "Sequence.h"
-#include "Grid.h"
+
+#include "Marshaller.h"
+#include "UnMarshaller.h"
 
 #include "DDS.h"
 #include "util.h"
@@ -93,7 +91,7 @@ Float32::Float32(const string &n, const string &d)
 
 Float32::Float32(const Float32 &copy_from) : BaseType(copy_from)
 {
-    _buf = copy_from._buf;
+    d_buf = copy_from.d_buf;
 }
 
 BaseType *
@@ -110,13 +108,13 @@ Float32::operator=(const Float32 &rhs)
 
     dynamic_cast<BaseType &>(*this) = rhs;
 
-    _buf = rhs._buf;
+    d_buf = rhs.d_buf;
 
     return *this;
 }
 
 unsigned int
-Float32::width()
+Float32::width(bool)
 {
     return sizeof(dods_float32);
 }
@@ -137,7 +135,7 @@ Float32::serialize(ConstraintEvaluator &eval, DDS &dds,
 
     dds.timeout_off();
 
-    m.put_float32( _buf ) ;
+    m.put_float32( d_buf ) ;
 
     return true;
 }
@@ -145,7 +143,7 @@ Float32::serialize(ConstraintEvaluator &eval, DDS &dds,
 bool
 Float32::deserialize(UnMarshaller &um, DDS *, bool)
 {
-    um.get_float32( _buf ) ;
+    um.get_float32( d_buf ) ;
 
     return false;
 }
@@ -162,7 +160,7 @@ Float32::val2buf(void *val, bool)
         throw InternalErr(__FILE__, __LINE__,
                           "The incoming pointer does not contain any data.");
 
-    _buf = *(dods_float32 *)val;
+    d_buf = *(dods_float32 *)val;
 
     return width();
 }
@@ -178,7 +176,7 @@ Float32::buf2val(void **val)
     if (!*val)
         *val = new dods_float32;
 
-    *(dods_float32 *)*val = _buf;
+    *(dods_float32 *)*val = d_buf;
 
     return width();
 }
@@ -186,7 +184,7 @@ Float32::buf2val(void **val)
 bool
 Float32::set_value(dods_float32 f)
 {
-    _buf = f;
+    d_buf = f;
     set_read_p(true);
 
     return true;
@@ -200,24 +198,16 @@ Float32::set_value(dods_float32 f)
 dods_float32
 Float32::value() const
 {
-    return _buf;
+    return d_buf;
 }
 
-#if FILE_METHODS
 void
 Float32::print_val(FILE *out, string space, bool print_decl_p)
 {
-    // FIX: need to set precision in the printing somehow.
-    // os.precision(DODS_FLT_DIG);
-
-    if (print_decl_p) {
-        print_decl(out, space, false);
-        fprintf(out, " = %.6g;\n", _buf) ;
-    }
-    else
-        fprintf(out, "%.6g", _buf) ;
+    ostringstream oss;
+    print_val(oss, space, print_decl_p);
+    fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
-#endif
 
 void
 Float32::print_val(ostream &out, string space, bool print_decl_p)
@@ -227,10 +217,10 @@ Float32::print_val(ostream &out, string space, bool print_decl_p)
 
     if (print_decl_p) {
         print_decl(out, space, false);
-	out << " = " << std::setprecision( 6 ) << _buf << ";\n" ;
+	out << " = " << std::setprecision( 6 ) << d_buf << ";\n" ;
     }
     else
-	out << std::setprecision( 6 ) << _buf ;
+	out << std::setprecision( 6 ) << d_buf ;
 }
 
 bool
@@ -251,29 +241,28 @@ Float32::ops(BaseType *b, int op)
     }
 
     switch (b->type()) {
-    case dods_byte_c:
-        return rops<dods_float32, dods_byte, Cmp<dods_float32, dods_byte> >
-               (_buf, dynamic_cast<Byte *>(b)->_buf, op);
-    case dods_int16_c:
-        return rops<dods_float32, dods_int16, Cmp<dods_float32, dods_int16> >
-               (_buf, dynamic_cast<Int16 *>(b)->_buf, op);
-    case dods_uint16_c:
-        return rops<dods_float32, dods_uint16, Cmp<dods_float32, dods_uint16> >
-               (_buf, dynamic_cast<UInt16 *>(b)->_buf, op);
-    case dods_int32_c:
-        return rops<dods_float32, dods_int32, Cmp<dods_float32, dods_int32> >
-               (_buf, dynamic_cast<Int32 *>(b)->_buf, op);
-    case dods_uint32_c:
-        return rops<dods_float32, dods_uint32, Cmp<dods_float32, dods_uint32> >
-               (_buf, dynamic_cast<UInt32 *>(b)->_buf, op);
-    case dods_float32_c:
-        return rops<dods_float32, dods_float32, Cmp<dods_float32, dods_float32> >
-               (_buf, dynamic_cast<Float32 *>(b)->_buf, op);
-    case dods_float64_c:
-        return rops<dods_float32, dods_float64, Cmp<dods_float32, dods_float64> >
-               (_buf, dynamic_cast<Float64 *>(b)->_buf, op);
-    default:
-        return false;
+        case dods_int8_c:
+            return Cmp<dods_float32, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
+        case dods_byte_c:
+            return SUCmp<dods_float32, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
+        case dods_int16_c:
+            return Cmp<dods_float32, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
+        case dods_uint16_c:
+            return SUCmp<dods_float32, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
+        case dods_int32_c:
+            return Cmp<dods_float32, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
+        case dods_uint32_c:
+            return SUCmp<dods_float32, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
+        case dods_int64_c:
+            return Cmp<dods_float32, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
+        case dods_uint64_c:
+            return SUCmp<dods_float32, dods_uint64>(op, d_buf, static_cast<UInt64*>(b)->value());
+        case dods_float32_c:
+            return Cmp<dods_float32, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
+        case dods_float64_c:
+            return Cmp<dods_float32, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
+        default:
+            return false;
     }
 }
 
@@ -292,7 +281,7 @@ Float32::dump(ostream &strm) const
 	 << endl ;
     DapIndent::Indent() ;
     BaseType::dump(strm) ;
-    strm << DapIndent::LMarg << "value: " << _buf << endl ;
+    strm << DapIndent::LMarg << "value: " << d_buf << endl ;
     DapIndent::UnIndent() ;
 }
 
