@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -37,6 +37,7 @@
 
 // #define DODS_DEBUG
 
+#include <sstream>
 #include <functional>
 #include <algorithm>
 
@@ -46,7 +47,7 @@
 #include "util.h"
 #include "InternalErr.h"
 #include "escaping.h"
-
+#include "XDRStreamMarshaller.h"
 #include "debug.h"
 
 using namespace std;
@@ -54,22 +55,22 @@ using namespace std;
 namespace libdap {
 
 void
-Grid::_duplicate(const Grid &s)
+Grid::m_duplicate(const Grid &s)
 {
-    // Clear out any spurious vars in Constructor::_vars
-    _vars.clear(); // [mjohnson 10 Sep 2009]
+    // Clear out any spurious vars in Constructor::d_vars
+    d_vars.clear(); // [mjohnson 10 Sep 2009]
 
-    _array_var = s._array_var->ptr_duplicate();
-    _array_var->set_parent(this);
-    _vars.push_back(_array_var); // so the Constructor::Vars_Iter sees it [mjohnson 10 Sep 2009]
+    d_array_var = s.d_array_var->ptr_duplicate();
+    d_array_var->set_parent(this);
+    d_vars.push_back(d_array_var); // so the Constructor::Vars_Iter sees it [mjohnson 10 Sep 2009]
 
     Grid &cs = const_cast<Grid &>(s);
 
-    for (Map_iter i = cs._map_vars.begin(); i != cs._map_vars.end(); i++) {
+    for (Map_iter i = cs.d_map_vars.begin(); i != cs.d_map_vars.end(); i++) {
         BaseType *btp = (*i)->ptr_duplicate();
         btp->set_parent(this);
-        _map_vars.push_back(btp);
-        _vars.push_back(btp); // push all map vectors as weak refs into super::_vars which won't delete them [mjohnson 10 Sep 2009]
+        d_map_vars.push_back(btp);
+        d_vars.push_back(btp); // push all map vectors as weak refs into super::d_vars which won't delete them [mjohnson 10 Sep 2009]
     }
 
 }
@@ -83,7 +84,7 @@ Grid::_duplicate(const Grid &s)
 
     @brief The Grid constructor.
 */
-Grid::Grid(const string &n) : Constructor(n, dods_grid_c), _array_var(0)
+Grid::Grid(const string &n) : Constructor(n, dods_grid_c), d_array_var(0)
 {}
 
 /** The Grid server-side constructor requires the name of the variable
@@ -98,20 +99,20 @@ Grid::Grid(const string &n) : Constructor(n, dods_grid_c), _array_var(0)
     @brief The Grid constructor.
 */
 Grid::Grid(const string &n, const string &d)
-    : Constructor(n, d, dods_grid_c), _array_var(0)
+    : Constructor(n, d, dods_grid_c), d_array_var(0)
 {}
 
 /** @brief The Grid copy constructor. */
 Grid::Grid(const Grid &rhs) : Constructor(rhs)
 {
-    _duplicate(rhs);
+    m_duplicate(rhs);
 }
 
 Grid::~Grid()
 {
-    delete _array_var; _array_var = 0;
+    delete d_array_var; d_array_var = 0;
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         BaseType *btp = *i ;
         delete btp ; btp = 0;
     }
@@ -129,35 +130,46 @@ Grid::operator=(const Grid &rhs)
     if (this == &rhs)
         return *this;
 
-    delete _array_var; _array_var = 0;
+    delete d_array_var; d_array_var = 0;
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         BaseType *btp = *i ;
         delete btp ;
     }
 
-    // this doesn't copy Constructor::_vars so...
+    // this doesn't copy Constructor::d_vars so...
     dynamic_cast<Constructor &>(*this) = rhs;
 
     // we do it in here...
-    _duplicate(rhs);
+    m_duplicate(rhs);
 
     return *this;
 }
 
+/**
+ * Grid can only be used for DAP2.
+ * @note This might change depending on just how complex DAP4Array becomes,
+ * for example.
+ */
+bool
+Grid::is_dap2_only_type()
+{
+    return true;
+}
+
 int
 Grid::element_count(bool leaves)
 {
     if (!leaves)
-        return _map_vars.size() + 1;
+        return d_map_vars.size() + 1;
     else {
         int i = 0;
-        for (Map_iter j = _map_vars.begin(); j != _map_vars.end(); j++) {
+        for (Map_iter j = d_map_vars.begin(); j != d_map_vars.end(); j++) {
             j += (*j)->element_count(leaves);
         }
 
 		if (!get_array())
-			throw InternalErr(__FILE__, __LINE__, "No Grid arry!");
+			throw InternalErr(__FILE__, __LINE__, "No Grid array!");
 
         i += get_array()->element_count(leaves);
         return i;
@@ -167,9 +179,9 @@ Grid::element_count(bool leaves)
 void
 Grid::set_send_p(bool state)
 {
-    _array_var->set_send_p(state);
+    d_array_var->set_send_p(state);
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         (*i)->set_send_p(state);
     }
 
@@ -179,9 +191,9 @@ Grid::set_send_p(bool state)
 void
 Grid::set_read_p(bool state)
 {
-    _array_var->set_read_p(state);
+    d_array_var->set_read_p(state);
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         (*i)->set_read_p(state);
     }
 
@@ -191,26 +203,59 @@ Grid::set_read_p(bool state)
 void
 Grid::set_in_selection(bool state)
 {
-    _array_var->set_in_selection(state);
+    d_array_var->set_in_selection(state);
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         (*i)->set_in_selection(state);
     }
 
     BaseType::set_in_selection(state);
 }
-
+#if 0
 unsigned int
-Grid::width()
+Grid::width(bool)
 {
-    unsigned int sz = _array_var->width();
+    unsigned int sz = d_array_var->width();
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         sz += (*i)->width();
     }
 
     return sz;
 }
+#endif
+/** This version of width simply returns the same thing as width() for simple
+    types and Arrays. For Structure it returns the total size if constrained
+    is false, or the size of the elements in the current projection if true.
+
+    @param constrained If true, return the size after applying a constraint.
+    @return  The number of bytes used by the variable.
+ */
+unsigned int
+Grid::width(bool constrained)
+{
+    unsigned int sz = 0;
+
+    if (constrained) {
+    	if (d_array_var->send_p())
+    		sz = d_array_var->width(constrained);
+    }
+    else {
+    	sz = d_array_var->width(constrained);
+    }
+
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
+    	if (constrained) {
+    		if ((*i)->send_p())
+    			sz += (*i)->width(constrained);
+    	}
+    	else {
+    		sz += (*i)->width(constrained);
+    	}
+    }
+
+    return sz;
+}
 
 void
 Grid::intern_data(ConstraintEvaluator &eval, DDS &dds)
@@ -222,10 +267,10 @@ Grid::intern_data(ConstraintEvaluator &eval, DDS &dds)
 
     dds.timeout_off();
 
-    if (_array_var->send_p())
-        _array_var->intern_data(eval, dds);
+    if (d_array_var->send_p())
+        d_array_var->intern_data(eval, dds);
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         if ((*i)->send_p()) {
             (*i)->intern_data(eval, dds);
         }
@@ -233,31 +278,59 @@ Grid::intern_data(ConstraintEvaluator &eval, DDS &dds)
 }
 
 bool
-Grid::serialize(ConstraintEvaluator &eval, DDS &dds,
-                Marshaller &m, bool ce_eval)
+Grid::serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval)
 {
+    DBG(cerr << "In Grid::serialize()" << endl);
+
     dds.timeout_on();
 
     // Re ticket 560: Get an object from eval that describes how to sample
     // and rearrange the data, then perform those actions. Alternative:
     // implement this as a selection function.
+    DBG(cerr << "In Grid::serialize(), before read() - read_p() returned: " << read_p() << endl);
 
     if (!read_p())
         read();  // read() throws Error and InternalErr
 
-#if EVAL
+    DBG(cerr << "In Grid::serialize(), past read() - read_p() returned: " << read_p() << endl);
+
+    #if EVAL
     if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #endif
 
     dds.timeout_off();
 
-    if (_array_var->send_p())
-        _array_var->serialize(eval, dds, m, false);
+    if (d_array_var->send_p()) {
+#ifdef CHECKSUMS
+        XDRStreamMarshaller *sm = dynamic_cast<XDRStreamMarshaller*>(&m);
+        if (sm && sm->checksums())
+            sm->reset_checksum();
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+        d_array_var->serialize(eval, dds, m, false);
+
+        if (sm && sm->checksums())
+            sm->get_checksum();
+#else
+        DBG(cerr << "About to call Array::serialize() in Grid::serialize" << endl);
+        d_array_var->serialize(eval, dds, m, false);
+#endif
+    }
+
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         if ((*i)->send_p()) {
+#ifdef CHECKSUMS
+            XDRStreamMarshaller *sm = dynamic_cast<XDRStreamMarshaller*>(&m);
+            if (sm && sm->checksums())
+                sm->reset_checksum();
+
             (*i)->serialize(eval, dds, m, false);
+
+            if (sm && sm->checksums())
+                sm->get_checksum();
+#else
+            (*i)->serialize(eval, dds, m, false);
+#endif
         }
     }
 
@@ -267,15 +340,16 @@ Grid::serialize(ConstraintEvaluator &eval, DDS &dds,
 bool
 Grid::deserialize(UnMarshaller &um, DDS *dds, bool reuse)
 {
-    _array_var->deserialize(um, dds, reuse);
+    d_array_var->deserialize(um, dds, reuse);
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         (*i)->deserialize(um, dds, reuse);
     }
 
     return false;
 }
 
+#if 0
 /** @brief Returns the size of the Grid type.
 
     Use the <tt>val2buf()</tt>
@@ -297,6 +371,7 @@ Grid::buf2val(void **)
 {
     return sizeof(Grid);
 }
+#endif
 
 BaseType *
 Grid::var(const string &n, btp_stack &s)
@@ -313,13 +388,13 @@ Grid::var(const string &n, bool, btp_stack *s)
 {
     string name = www2id(n);
 
-    if (_array_var->name() == name) {
+    if (d_array_var->name() == name) {
         if (s)
             s->push(static_cast<BaseType *>(this));
-        return _array_var;
+        return d_array_var;
     }
 
-    for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+    for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
         if ((*i)->name() == name) {
             if (s)
                 s->push(static_cast<BaseType *>(this));
@@ -345,12 +420,13 @@ Grid::var(const string &n, bool, btp_stack *s)
 void
 Grid::add_var(BaseType *bt, Part part)
 {
-    if (!bt) {
-        throw InternalErr(__FILE__, __LINE__,
-                          "Passing NULL pointer as variable to be added.");
-    }
-
-    if (part == array && _array_var) {
+    if (!bt)
+        throw InternalErr(__FILE__, __LINE__, "Passing NULL pointer as variable to be added.");
+#if 0
+    if (bt->is_dap4_only_type())
+        throw InternalErr(__FILE__, __LINE__, "Attempt to add a DAP4 type to a DAP2 Grid.");
+#endif
+    if (part == array && d_array_var) {
       // Avoid leaking memory...  Function is add, not set, so it is an error to call again for the array part.
       throw InternalErr(__FILE__, __LINE__, "Error: Grid::add_var called with part==Array, but the array was already set!");
     }
@@ -377,12 +453,12 @@ Grid::add_var(BaseType *bt, Part part)
     case maps: {
             bt_clone = bt->ptr_duplicate();
             bt_clone->set_parent(this);
-            _map_vars.push_back(bt_clone);
+            d_map_vars.push_back(bt_clone);
         }
     break;
 
     default: {
-        if (!_array_var) {
+        if (!d_array_var) {
             // Refactored to use new set_array ([mjohnson 11 nov 2009])
             Array* p_arr = dynamic_cast<Array*>(bt);
             // avoid obvious broken semantics
@@ -397,7 +473,7 @@ Grid::add_var(BaseType *bt, Part part)
         else {
             bt_clone = bt->ptr_duplicate();
             bt_clone->set_parent(this);
-            _map_vars.push_back(bt_clone);
+            d_map_vars.push_back(bt_clone);
         }
     }
     break;
@@ -405,9 +481,86 @@ Grid::add_var(BaseType *bt, Part part)
 
   // if we get ehre without exception, add the cloned object to the superclass variable iterator
   // mjohnson 10 Sep 2009
-  // Add it to the superclass _vars list so we can iterate on superclass vars
+  // Add it to the superclass d_vars list so we can iterate on superclass vars
   if (bt_clone) {
-    _vars.push_back(bt_clone);
+    d_vars.push_back(bt_clone);
+  }
+}
+
+/** Add an array or map to the Grid.
+
+    @note The original version of this method required that the \c part parameter
+    be present. However, this complicates using the class from a parser
+    (e.g., the schema-based XML parser). I have modified the method so that
+    if \c part is nil (the default), then the first variable added is the
+    array and subsequent variables are maps. This matches the behavior in the
+    Java DAP implementation.
+
+    @note This version of the method does not the BaseType before adding it.
+    The caller must not free the BaseType object.
+
+    @param bt Array or Map variable
+    @param part is this an array or a map. If not present, first \c bt is the
+    array and subsequent <tt>bt</tt>s are maps. */
+void
+Grid::add_var_nocopy(BaseType *bt, Part part)
+{
+    if (!bt)
+        throw InternalErr(__FILE__, __LINE__, "Passing NULL pointer as variable to be added.");
+#if 0
+    if (bt->is_dap4_only_type())
+        throw InternalErr(__FILE__, __LINE__, "Attempt to add a DAP4 type to a DAP2 Grid.");
+#endif
+    if (part == array && d_array_var) {
+      // Avoid leaking memory...  Function is add, not set, so it is an error to call again for the array part.
+      throw InternalErr(__FILE__, __LINE__, "Error: Grid::add_var called with part==Array, but the array was already set!");
+    }
+
+    bt->set_parent(this);
+
+    switch (part) {
+
+    case array: {
+        // Refactored to use new set_array ([mjohnson 11 nov 2009])
+        Array* p_arr = dynamic_cast<Array*>(bt);
+        // avoid obvious broken semantics
+        if (!p_arr) {
+          throw InternalErr(__FILE__, __LINE__,
+              "Grid::add_var(): with Part==array: object is not an Array!");
+        }
+        set_array(static_cast<Array*>(bt));
+    }
+    break;
+
+    case maps: {
+            //bt->set_parent(this);
+            d_map_vars.push_back(bt);
+        }
+    break;
+
+    default: {
+        if (!d_array_var) {
+            // Refactored to use new set_array ([mjohnson 11 nov 2009])
+            Array* p_arr = dynamic_cast<Array*>(bt);
+            // avoid obvious broken semantics
+            if (!p_arr) {
+              throw InternalErr(__FILE__, __LINE__,
+                  "Grid::add_var(): with Part==array: object is not an Array!");
+            }
+            set_array(static_cast<Array*>(bt));
+        }
+        else {
+            d_map_vars.push_back(bt);
+        }
+    }
+    break;
+  }// switch
+
+  // if we get here without exception, add the cloned object to the superclass variable iterator
+  // mjohnson 10 Sep 2009
+  // Add it to the superclass d_vars list so we can iterate on superclass vars
+  if (bt) {
+    d_vars.push_back(bt);
   }
 }
 
@@ -428,14 +581,14 @@ Grid::set_array(Array* p_new_arr)
         "Grid::set_array(): Cannot set to null!");
   }
   // Make sure not same memory, this would be evil.
-  if (p_new_arr == _array_var) {
+  if (p_new_arr == d_array_var) {
       return;
    }
   // clean out any old array
-  delete _array_var; _array_var = 0;
+  delete d_array_var; d_array_var = 0;
   // Set the new, with parent
-  _array_var = p_new_arr;
-  _array_var->set_parent(this);
+  d_array_var = p_new_arr;
+  d_array_var->set_parent(this);
 }
 
 /**
@@ -467,18 +620,18 @@ Grid::set_array(Array* p_new_arr)
 Array*
 Grid::add_map(Array* p_new_map, bool add_as_copy)
 {
-  if (!p_new_map) {
-    throw InternalErr(__FILE__, __LINE__,
-        "Grid::add_map(): cannot have p_new_map null!");
-  }
-
-  if (add_as_copy) {
+  if (!p_new_map)
+    throw InternalErr(__FILE__, __LINE__, "Grid::add_map(): cannot have p_new_map null!");
+#if 0
+  if (p_new_map->is_dap4_only_type())
+      throw InternalErr(__FILE__, __LINE__, "Attempt to add a DAP4 type to a DAP2 Grid.");
+#endif
+  if (add_as_copy)
     p_new_map = static_cast<Array*>(p_new_map->ptr_duplicate());
-  }
 
   p_new_map->set_parent(this);
-  _map_vars.push_back(p_new_map);
-  _vars.push_back(p_new_map); // allow superclass iter to work as well.
+  d_map_vars.push_back(p_new_map);
+  d_vars.push_back(p_new_map); // allow superclass iter to work as well.
 
   // return the one that got put into the Grid.
   return p_new_map;
@@ -505,8 +658,8 @@ Grid::prepend_map(Array* p_new_map, bool add_copy)
     }
 
   p_new_map->set_parent(this);
-  _map_vars.insert(_map_vars.begin(), p_new_map);
-  _vars.insert(_vars.begin(), p_new_map); // allow superclass iter to work as well.
+  d_map_vars.insert(d_map_vars.begin(), p_new_map);
+  d_vars.insert(d_vars.begin(), p_new_map); // allow superclass iter to work as well.
 
    // return the one that got put into the Grid.
    return p_new_map;
@@ -518,7 +671,7 @@ Grid::prepend_map(Array* p_new_map, bool add_copy)
 BaseType *
 Grid::array_var()
 {
-    return _array_var;
+    return d_array_var;
 }
 
 /** @brief Returns the Grid Array.
@@ -527,7 +680,7 @@ Grid::array_var()
 Array *
 Grid::get_array()
 {
-    Array *a = dynamic_cast<Array*>(_array_var);
+    Array *a = dynamic_cast<Array*>(d_array_var);
     if (a)
         return a;
     else
@@ -538,7 +691,7 @@ Grid::get_array()
 Grid::Map_iter
 Grid::map_begin()
 {
-    return _map_vars.begin() ;
+    return d_map_vars.begin() ;
 }
 
 /** Returns an iterator referencing the end of the list of Map vectors.
@@ -546,14 +699,14 @@ Grid::map_begin()
 Grid::Map_iter
 Grid::map_end()
 {
-    return _map_vars.end() ;
+    return d_map_vars.end() ;
 }
 
 /** @brief Returns an iterator referencing the first Map vector. */
 Grid::Map_riter
 Grid::map_rbegin()
 {
-    return _map_vars.rbegin() ;
+    return d_map_vars.rbegin() ;
 }
 
 /** Returns an iterator referencing the end of the list of Map vectors.
@@ -561,7 +714,7 @@ Grid::map_rbegin()
 Grid::Map_riter
 Grid::map_rend()
 {
-    return _map_vars.rend() ;
+    return d_map_vars.rend() ;
 }
 
 /** Return the iterator for the \e ith map.
@@ -570,7 +723,7 @@ Grid::map_rend()
 Grid::Map_iter
 Grid::get_map_iter(int i)
 {
-    return _map_vars.begin() + i;
+    return d_map_vars.begin() + i;
 }
 
 /** Returns the number of components in the Grid object.  This is
@@ -594,16 +747,16 @@ Grid::components(bool constrained)
     int comp;
 
     if (constrained) {
-        comp = _array_var->send_p() ? 1 : 0;
+        comp = d_array_var->send_p() ? 1 : 0;
 
-        for (Map_iter i = _map_vars.begin(); i != _map_vars.end(); i++) {
+        for (Map_iter i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
             if ((*i)->send_p()) {
                 comp++;
             }
         }
     }
     else {
-        comp = 1 + _map_vars.size();
+        comp = 1 + d_map_vars.size();
     }
 
     return comp;
@@ -670,7 +823,7 @@ Grid::projection_yields_grid()
     // projected dimension in the Array component, there is a matching Map
     // vector, then the Grid is valid.
     bool valid = true;
-    Array *a = (Array *)_array_var;
+    Array *a = (Array *)d_array_var;
 
     // Don't bother checking if the Array component is not included.
     if (!a->send_p())
@@ -709,68 +862,19 @@ Grid::projection_yields_grid()
 void
 Grid::clear_constraint()
 {
-    dynamic_cast<Array&>(*_array_var).clear_constraint();
+    dynamic_cast<Array&>(*d_array_var).clear_constraint();
     for (Map_iter m = map_begin(); m != map_end(); ++m)
         dynamic_cast<Array&>(*(*m)).clear_constraint();
 }
 
-#if FILE_METHODS
 void
 Grid::print_decl(FILE *out, string space, bool print_semi,
                  bool constraint_info, bool constrained)
 {
-    if (constrained && !send_p())
-        return;
-
-    // The problem with the above is that if two Grids are projected and each
-    // contain one variable, say a map, and it happens to have the same name
-    // in each Grid, then without the enclosing Structures, the returned dataset
-    // has two variables with the same name at the same lexical level. So I'm
-    // removing the code above.
-    if (constrained && !projection_yields_grid()) {
-        fprintf(out, "%sStructure {\n", space.c_str()) ;
-
-        _array_var->print_decl(out, space + "    ", true, constraint_info,
-                               constrained);
-
-        for (Map_citer i = _map_vars.begin(); i != _map_vars.end(); i++) {
-            (*i)->print_decl(out, space + "    ", true,
-                             constraint_info, constrained);
-        }
-
-        fprintf(out, "%s} %s", space.c_str(), id2www(name()).c_str()) ;
-    }
-    else {
-        // The number of elements in the (projected) Grid must be such that
-        // we have a valid Grid object; send it as such.
-        fprintf(out, "%s%s {\n", space.c_str(), type_name().c_str()) ;
-
-        fprintf(out, "%s  Array:\n", space.c_str()) ;
-        _array_var->print_decl(out, space + "    ", true, constraint_info,
-                               constrained);
-
-        fprintf(out, "%s  Maps:\n", space.c_str()) ;
-        for (Map_citer i = _map_vars.begin(); i != _map_vars.end(); i++) {
-            (*i)->print_decl(out, space + "    ", true,
-                             constraint_info, constrained);
-        }
-
-        fprintf(out, "%s} %s", space.c_str(), id2www(name()).c_str()) ;
-    }
-
-    if (constraint_info) {
-        if (send_p())
-            fprintf( out, ": Send True");
-        else
-            fprintf( out, ": Send False");
-    }
-
-    if (print_semi)
-        fprintf(out, ";\n") ;
-
-    return;
+    ostringstream oss;
+    print_decl(oss, space, print_semi, constraint_info, constrained);
+    fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
-#endif
 
 void
 Grid::print_decl(ostream &out, string space, bool print_semi,
@@ -783,10 +887,10 @@ Grid::print_decl(ostream &out, string space, bool print_semi,
     if (constrained && !projection_yields_grid()) {
 	out << space << "Structure {\n" ;
 
-        _array_var->print_decl(out, space + "    ", true, constraint_info,
+        d_array_var->print_decl(out, space + "    ", true, constraint_info,
                                constrained);
 
-        for (Map_citer i = _map_vars.begin(); i != _map_vars.end(); i++) {
+        for (Map_citer i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
             (*i)->print_decl(out, space + "    ", true,
                              constraint_info, constrained);
         }
@@ -799,11 +903,11 @@ Grid::print_decl(ostream &out, string space, bool print_semi,
 	out << space << type_name() << " {\n" ;
 
 	out << space << "  Array:\n" ;
-        _array_var->print_decl(out, space + "    ", true, constraint_info,
+        d_array_var->print_decl(out, space + "    ", true, constraint_info,
                                constrained);
 
 	out << space << "  Maps:\n" ;
-        for (Map_citer i = _map_vars.begin(); i != _map_vars.end(); i++) {
+        for (Map_citer i = d_map_vars.begin(); i != d_map_vars.end(); i++) {
             (*i)->print_decl(out, space + "    ", true,
                              constraint_info, constrained);
         }
@@ -824,79 +928,37 @@ Grid::print_decl(ostream &out, string space, bool print_semi,
     return;
 }
 
-#if FILE_METHODS
-class PrintMapField : public unary_function<BaseType *, void>
-{
-    FILE *d_out;
-    string d_space;
-    bool d_constrained;
-    string d_tag;
-public:
-    PrintMapField(FILE *o, string s, bool c, const string &t = "Map")
-            : d_out(o), d_space(s), d_constrained(c), d_tag(t)
-    {}
-
-    void operator()(BaseType *btp)
-    {
-        Array *a = dynamic_cast<Array*>(btp);
-        if (!a)
-            throw InternalErr(__FILE__, __LINE__, "Expected an Array.");
-        a->print_xml_core(d_out, d_space, d_constrained, d_tag);
-    }
-};
-
+/**
+ * @deprecated
+ */
 void
 Grid::print_xml(FILE *out, string space, bool constrained)
 {
-    if (constrained && !send_p())
-         return;
-
-     if (constrained && !projection_yields_grid()) {
-         fprintf(out, "%s<Structure", space.c_str());
-         if (!name().empty())
-             fprintf(out, " name=\"%s\"", id2xml(name()).c_str());
-
-         fprintf(out, ">\n");
-
-         get_attr_table().print_xml(out, space + "    ", constrained);
-
-         get_array()->print_xml(out, space + "    ", constrained);
-
-         for_each(map_begin(), map_end(),
-                  PrintMapField(out, space + "    ", constrained, "Array"));
-
-         fprintf(out, "%s</Structure>\n", space.c_str());
-     }
-     else {
-         // The number of elements in the (projected) Grid must be such that
-         // we have a valid Grid object; send it as such.
-         fprintf(out, "%s<Grid", space.c_str());
-         if (!name().empty())
-             fprintf(out, " name=\"%s\"", id2xml(name()).c_str());
-
-         fprintf(out, ">\n");
-
-         get_attr_table().print_xml(out, space + "    ", constrained);
-
-         get_array()->print_xml(out, space + "    ", constrained);
-
-         for_each(map_begin(), map_end(),
-                  PrintMapField(out, space + "    ", constrained));
-
-         fprintf(out, "%s</Grid>\n", space.c_str());
-     }
+    XMLWriter xml(space);
+    print_xml_writer(xml, constrained);
+    fwrite(xml.get_doc(), sizeof(char), xml.get_doc_size(), out);
 }
-#endif
 
-class PrintMapFieldStrm : public unary_function<BaseType *, void>
+/**
+ * @deprecated
+ */
+void
+Grid::print_xml(ostream &out, string space, bool constrained)
 {
-    ostream &d_out;
-    string d_space;
+    XMLWriter xml(space);
+    print_xml_writer(xml, constrained);
+    out << xml.get_doc();
+}
+
+
+class PrintGridFieldXMLWriter : public unary_function<BaseType *, void>
+{
+    XMLWriter &d_xml;
     bool d_constrained;
     string d_tag;
 public:
-    PrintMapFieldStrm(ostream &o, string s, bool c, const string &t = "Map")
-            : d_out(o), d_space(s), d_constrained(c), d_tag(t)
+    PrintGridFieldXMLWriter(XMLWriter &x, bool c, const string &t = "Map")
+            : d_xml(x), d_constrained(c), d_tag(t)
     {}
 
     void operator()(BaseType *btp)
@@ -904,83 +966,63 @@ public:
         Array *a = dynamic_cast<Array*>(btp);
         if (!a)
             throw InternalErr(__FILE__, __LINE__, "Expected an Array.");
-        a->print_xml_core(d_out, d_space, d_constrained, d_tag);
+        a->print_xml_writer_core(d_xml, d_constrained, d_tag);
     }
 };
 
 void
-Grid::print_xml(ostream &out, string space, bool constrained)
+Grid::print_xml_writer(XMLWriter &xml, bool constrained)
 {
     if (constrained && !send_p())
         return;
 
     if (constrained && !projection_yields_grid()) {
-        out << space << "<Structure" ;
+        if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*)"Structure") < 0)
+            throw InternalErr(__FILE__, __LINE__, "Could not write Structure element");
+
         if (!name().empty())
-            out << " name=\"" << id2xml(name()) << "\"" ;
+            if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)name().c_str()) < 0)
+                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
 
-        out << ">\n" ;
+        get_attr_table().print_xml_writer(xml);
 
-        get_attr_table().print_xml(out, space + "    ", constrained);
-
-        get_array()->print_xml(out, space + "    ", constrained);
+        get_array()->print_xml_writer(xml, constrained);
 
         for_each(map_begin(), map_end(),
-                 PrintMapFieldStrm(out, space + "    ", constrained, "Array"));
+                 PrintGridFieldXMLWriter(xml, constrained, "Array"));
 
-        out << space << "</Structure>\n" ;
+        if (xmlTextWriterEndElement(xml.get_writer()) < 0)
+            throw InternalErr(__FILE__, __LINE__, "Could not end Structure element");
     }
     else {
         // The number of elements in the (projected) Grid must be such that
         // we have a valid Grid object; send it as such.
-        out << space << "<Grid" ;
+        if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*)"Grid") < 0)
+            throw InternalErr(__FILE__, __LINE__, "Could not write Grid element");
+
         if (!name().empty())
-            out << " name=\"" << id2xml(name()) << "\"" ;
+            if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)name().c_str()) < 0)
+                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
 
-        out << ">\n" ;
+        get_attr_table().print_xml_writer(xml);
 
-        get_attr_table().print_xml(out, space + "    ", constrained);
-
-        get_array()->print_xml(out, space + "    ", constrained);
+        get_array()->print_xml_writer(xml, constrained);
 
         for_each(map_begin(), map_end(),
-                 PrintMapFieldStrm(out, space + "    ", constrained));
+                 PrintGridFieldXMLWriter(xml, constrained, "Map"));
 
-        out << space << "</Grid>\n" ;
+        if (xmlTextWriterEndElement(xml.get_writer()) < 0)
+            throw InternalErr(__FILE__, __LINE__, "Could not end Grid element");
     }
 }
 
-#if FILE_METHODS
 void
 Grid::print_val(FILE *out, string space, bool print_decl_p)
 {
-    if (print_decl_p) {
-        print_decl(out, space, false);
-        fprintf(out, " = ") ;
-    }
-
-    // If we are printing a value on the client-side, projection_yields_grid
-    // should not be called since we don't *have* a projection without a
-    // contraint. I think that if we are here and send_p() is not true, then
-    // the value of this function should be ignored. 4/6/2000 jhrg
-    bool pyg = projection_yields_grid(); // hack 12/1/99 jhrg
-    if (pyg || !send_p())
-        fprintf(out, "{  Array: ") ;
-    else
-        fprintf(out, "{") ;
-    _array_var->print_val(out, "", false);
-    if (pyg || !send_p())
-        fprintf(out, "  Maps: ") ;
-    for (Map_citer i = _map_vars.begin(); i != _map_vars.end();
-         i++, (void)(i != _map_vars.end() && fprintf(out, ", "))) {
-        (*i)->print_val(out, "", false);
-    }
-    fprintf(out, " }") ;
-
-    if (print_decl_p)
-        fprintf(out, ";\n") ;
+    ostringstream oss;
+    print_val(oss, space, print_decl_p);
+    fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
-#endif
 
 void
 Grid::print_val(ostream &out, string space, bool print_decl_p)
@@ -999,11 +1041,11 @@ Grid::print_val(ostream &out, string space, bool print_decl_p)
 	out << "{  Array: " ;
     else
 	out << "{" ;
-    _array_var->print_val(out, "", false);
+    d_array_var->print_val(out, "", false);
     if (pyg || !send_p())
 	out << "  Maps: " ;
-    for (Map_citer i = _map_vars.begin(); i != _map_vars.end();
-         i++, (void)(i != _map_vars.end() && out << ", ")) {
+    for (Map_citer i = d_map_vars.begin(); i != d_map_vars.end();
+         i++, (void)(i != d_map_vars.end() && out << ", ")) {
         (*i)->print_val(out, "", false);
     }
     out << " }" ;
@@ -1026,18 +1068,18 @@ Grid::check_semantics(string &msg, bool all)
 
     msg = "";
 
-    if (!_array_var) {
+    if (!d_array_var) {
         msg += "Null grid base array in `" + name() + "'\n";
         return false;
     }
 
     // Is it an array?
-    if (_array_var->type() != dods_array_c) {
-        msg += "Grid `" + name() + "'s' member `" + _array_var->name() + "' must be an array\n";
+    if (d_array_var->type() != dods_array_c) {
+        msg += "Grid `" + name() + "'s' member `" + d_array_var->name() + "' must be an array\n";
         return false;
     }
 
-    Array *av = (Array *)_array_var; // past test above, must be an array
+    Array *av = (Array *)d_array_var; // past test above, must be an array
 
     // Array must be of a simple_type.
     if (!av->var()->is_simple_type()) {
@@ -1046,7 +1088,7 @@ Grid::check_semantics(string &msg, bool all)
     }
 
     // enough maps?
-    if ((unsigned)_map_vars.size() != av->dimensions()) {
+    if ((unsigned)d_map_vars.size() != av->dimensions()) {
         msg += "The number of map variables for grid `" + this->name() + "' does not match the number of dimensions of `";
         msg += av->name() + "'\n";
         return false;
@@ -1054,8 +1096,8 @@ Grid::check_semantics(string &msg, bool all)
 
     const string array_var_name = av->name();
     Array::Dim_iter asi = av->dim_begin() ;
-    for (Map_iter mvi = _map_vars.begin();
-         mvi != _map_vars.end(); mvi++, asi++) {
+    for (Map_iter mvi = d_map_vars.begin();
+         mvi != d_map_vars.end(); mvi++, asi++) {
 
         BaseType *mv = *mvi;
 
@@ -1089,15 +1131,15 @@ Grid::check_semantics(string &msg, bool all)
         int av_size = av->dimension_size(asi) ;
         if (mv_a_size != av_size) {
             msg += "Grid map variable  `" + mv_a->name() + "'s' size does not match the size of array variable '";
-            msg += _array_var->name() + "'s' cooresponding dimension\n";
+            msg += d_array_var->name() + "'s' cooresponding dimension\n";
             return false;
         }
     }
 
     if (all) {
-        if (!_array_var->check_semantics(msg, true))
+        if (!d_array_var->check_semantics(msg, true))
             return false;
-        for (Map_iter mvi = _map_vars.begin(); mvi != _map_vars.end(); mvi++) {
+        for (Map_iter mvi = d_map_vars.begin(); mvi != d_map_vars.end(); mvi++) {
             if (!(*mvi)->check_semantics(msg, true)) {
                 return false;
             }
@@ -1122,10 +1164,10 @@ Grid::dump(ostream &strm) const
     << (void *)this << ")" << endl ;
     DapIndent::Indent() ;
     Constructor::dump(strm) ;
-    if (_array_var) {
+    if (d_array_var) {
         strm << DapIndent::LMarg << "array var: " << endl ;
         DapIndent::Indent() ;
-        _array_var->dump(strm) ;
+        d_array_var->dump(strm) ;
         DapIndent::UnIndent() ;
     }
     else {
@@ -1133,8 +1175,8 @@ Grid::dump(ostream &strm) const
     }
     strm << DapIndent::LMarg << "map var: " << endl ;
     DapIndent::Indent() ;
-    Map_citer i = _map_vars.begin() ;
-    Map_citer ie = _map_vars.end() ;
+    Map_citer i = d_map_vars.begin() ;
+    Map_citer ie = d_map_vars.end() ;
     for (; i != ie; i++) {
         (*i)->dump(strm) ;
     }
