@@ -19,17 +19,13 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
 
 #include "config.h"
 
-static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc 24380 2011-03-28 21:47:15Z jimg $"
-    };
-
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -49,7 +45,6 @@ static char rcsid[] not_used =
 #include <cstdlib>
 #include <cstring>
 
-// #define DODS_DEBUG
 //#define DODS_DEBUG2
 //#define HTTP_TRACE
 //#define DODS_DEBUG
@@ -448,6 +443,9 @@ HTTPConnect::read_url(const string &url, FILE *stream,
     // value/result parameter to get the raw response header information .
     curl_easy_setopt(d_curl, CURLOPT_WRITEHEADER, resp_hdrs);
 
+    // This is the call that causes curl to go and get the remote resource and "write it down"
+    // utilizing the configuration state that has been previously conditioned by various perturbations
+    // of calls to curl_easy_setopt().
     CURLcode res = curl_easy_perform(d_curl);
 
     // Free the header list and null the value in d_curl.
@@ -525,8 +523,7 @@ HTTPConnect::HTTPConnect(RCReader *rcr) : d_username(""), d_password(""),
 
     // HTTPCache::instance returns a valid ptr or 0.
     if (d_rcr->get_use_cache())
-        d_http_cache = HTTPCache::instance(d_rcr->get_dods_cache_root(),
-                                           true);
+        d_http_cache = HTTPCache::instance(d_rcr->get_dods_cache_root(),true);
     else
         d_http_cache = 0;
 
@@ -887,7 +884,7 @@ HTTPConnect::plain_fetch_url(const string &url)
     try {
         status = read_url(url, stream, resp_hdrs); // Throws Error.
         if (status >= 400) {
-        	delete resp_hdrs;
+        	// delete resp_hdrs; resp_hdrs = 0;
             string msg = "Error while reading the URL: ";
             msg += url;
             msg += ".\nThe OPeNDAP server returned the following message:\n";
