@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -30,7 +30,8 @@
 #include <string>
 
 #include <curl/curl.h>
-#include <curl/types.h>
+//No longer used in CURL - pwest April 09, 2012
+//#include <curl/types.h>
 #include <curl/easy.h>
 
 #ifndef _rc_reader_h_
