@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -36,23 +36,24 @@
 
 #include "config.h"
 
-static char rcsid[] not_used =
-    {"$Id: Int16.cc 21699 2009-11-05 00:06:01Z jimg $"
-    };
+#include <sstream>
 
-#include "Byte.h"
+#include "Byte.h"           // synonymous with UInt8 and Char
+#include "Int8.h"
 #include "Int16.h"
 #include "UInt16.h"
 #include "Int32.h"
 #include "UInt32.h"
+#include "Int64.h"
+#include "UInt64.h"
 #include "Float32.h"
 #include "Float64.h"
 #include "Str.h"
 #include "Url.h"
-#include "Array.h"
-#include "Structure.h"
-#include "Sequence.h"
-#include "Grid.h"
+
+
+#include "Marshaller.h"
+#include "UnMarshaller.h"
 
 #include "DDS.h"
 #include "util.h"
@@ -86,7 +87,7 @@ Int16::Int16(const string &n, const string &d) : BaseType(n, d, dods_int16_c)
 
 Int16::Int16(const Int16 &copy_from) : BaseType(copy_from)
 {
-    _buf = copy_from._buf;
+    d_buf = copy_from.d_buf;
 }
 
 BaseType *
@@ -103,13 +104,13 @@ Int16::operator=(const Int16 &rhs)
 
     dynamic_cast<BaseType &>(*this) = rhs;
 
-    _buf = rhs._buf;
+    d_buf = rhs.d_buf;
 
     return *this;
 }
 
 unsigned int
-Int16::width()
+Int16::width(bool)
 {
     return sizeof(dods_int16);
 }
@@ -130,7 +131,7 @@ Int16::serialize(ConstraintEvaluator &eval, DDS &dds,
 
     dds.timeout_off();
 
-    m.put_int16( _buf ) ;
+    m.put_int16( d_buf ) ;
 
     return true;
 }
@@ -138,7 +139,7 @@ Int16::serialize(ConstraintEvaluator &eval, DDS &dds,
 bool
 Int16::deserialize(UnMarshaller &um, DDS *, bool)
 {
-    um.get_int16( _buf ) ;
+    um.get_int16( d_buf ) ;
 
     return false;
 }
@@ -154,7 +155,7 @@ Int16::val2buf(void *val, bool)
         throw InternalErr(__FILE__, __LINE__,
                           "The incoming pointer does not contain any data.");
 
-    _buf = *(dods_int16 *)val;
+    d_buf = *(dods_int16 *)val;
 
     return width();
 }
@@ -170,7 +171,7 @@ Int16::buf2val(void **val)
     if (!*val)
         *val = new dods_int16;
 
-    *(dods_int16 *)*val = _buf;
+    *(dods_int16 *)*val = d_buf;
 
     return width();
 }
@@ -178,40 +179,35 @@ Int16::buf2val(void **val)
 dods_int16
 Int16::value() const
 {
-    return _buf;
+    return d_buf;
 }
 
 bool
 Int16::set_value(dods_int16 i)
 {
-    _buf = i;
+    d_buf = i;
     set_read_p(true);
 
     return true;
 }
 
-#if FILE_METHODS
 void
 Int16::print_val(FILE *out, string space, bool print_decl_p)
 {
-    if (print_decl_p) {
-        print_decl(out, space, false);
-        fprintf(out, " = %d;\n", _buf) ;
-    }
-    else
-        fprintf(out, "%d", _buf) ;
+    ostringstream oss;
+    print_val(oss, space, print_decl_p);
+    fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
-#endif
 
 void
 Int16::print_val(ostream &out, string space, bool print_decl_p)
 {
     if (print_decl_p) {
         print_decl(out, space, false);
-	out << " = " << _buf << ";\n" ;
+	out << " = " << d_buf << ";\n" ;
     }
     else
-	out << _buf ;
+	out << d_buf ;
 }
 
 bool
@@ -239,29 +235,28 @@ Int16::ops(BaseType *b, int op)
     }
 
     switch (b->type()) {
-    case dods_byte_c:
-        return rops<dods_int16, dods_byte, SUCmp<dods_int16, dods_byte> >
-               (_buf, dynamic_cast<Byte *>(b)->_buf, op);
-    case dods_int16_c:
-        return rops<dods_int16, dods_int16, Cmp<dods_int16, dods_int16> >
-               (_buf, dynamic_cast<Int16 *>(b)->_buf, op);
-    case dods_uint16_c:
-        return rops<dods_int16, dods_uint16, SUCmp<dods_int16, dods_uint16> >
-               (_buf, dynamic_cast<UInt16 *>(b)->_buf, op);
-    case dods_int32_c:
-        return rops<dods_int16, dods_int32, Cmp<dods_int16, dods_int32> >
-               (_buf, dynamic_cast<Int32 *>(b)->_buf, op);
-    case dods_uint32_c:
-        return rops<dods_int16, dods_uint32, SUCmp<dods_int16, dods_uint32> >
-               (_buf, dynamic_cast<UInt32 *>(b)->_buf, op);
-    case dods_float32_c:
-        return rops<dods_int16, dods_float32, Cmp<dods_int16, dods_float32> >
-               (_buf, dynamic_cast<Float32 *>(b)->_buf, op);
-    case dods_float64_c:
-        return rops<dods_int16, dods_float64, Cmp<dods_int16, dods_float64> >
-               (_buf, dynamic_cast<Float64 *>(b)->_buf, op);
-    default:
-        return false;
+        case dods_int8_c:
+            return Cmp<dods_int16, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
+        case dods_byte_c:
+            return SUCmp<dods_int16, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
+        case dods_int16_c:
+            return Cmp<dods_int16, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
+        case dods_uint16_c:
+            return SUCmp<dods_int16, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
+        case dods_int32_c:
+            return Cmp<dods_int16, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
+        case dods_uint32_c:
+            return SUCmp<dods_int16, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
+        case dods_int64_c:
+            return Cmp<dods_int16, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
+        case dods_uint64_c:
+            return SUCmp<dods_int16, dods_uint64>(op, d_buf, static_cast<UInt64*>(b)->value());
+        case dods_float32_c:
+            return Cmp<dods_int16, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
+        case dods_float64_c:
+            return Cmp<dods_int16, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
+        default:
+            return false;
     }
 }
 
@@ -280,7 +275,7 @@ Int16::dump(ostream &strm) const
     << (void *)this << ")" << endl ;
     DapIndent::Indent() ;
     BaseType::dump(strm) ;
-    strm << DapIndent::LMarg << "value: " << _buf << endl ;
+    strm << DapIndent::LMarg << "value: " << d_buf << endl ;
     DapIndent::UnIndent() ;
 }
 
