@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -37,7 +37,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: RValue.cc 24281 2011-03-09 00:22:31Z jimg $"
+    {"$Id: RValue.cc 27197 2013-10-01 21:29:54Z jimg $"
     };
 
 #include <cassert>
@@ -109,15 +109,17 @@ build_btp_args(rvalue_list *args, DDS &dds)
         for (rvalue::Args_iter i = args->begin(); i != args->end() && index
                 < argc + 1; ++i)
             argv[index++] = (*i)->bvalue(dds);
+
+        argv[index] = 0; // Add the null terminator.
     }
 
     if (index != argc) {
         delete[] argv;
         throw InternalErr(__FILE__, __LINE__, "index out of range.");
     }
-
+#if 0
     argv[index] = 0; // Add the null terminator.
-
+#endif
     return argv;
 }
 
