@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -68,6 +68,14 @@ typedef std::vector<rvalue *> rvalue_list;
 typedef std::vector<rvalue *>::const_iterator rvalue_list_citer ;
 typedef std::vector<rvalue *>::iterator rvalue_list_iter ;
 
+typedef std::vector<dods_byte> *byte_arg_list;
+typedef std::vector<dods_int16> *int16_arg_list;
+typedef std::vector<dods_uint16> *uint16_arg_list;
+typedef std::vector<dods_int32> *int32_arg_list;
+typedef std::vector<dods_uint32> *uint32_arg_list;
+typedef std::vector<dods_float32> *float32_arg_list;
+typedef std::vector<dods_float64> *float64_arg_list;
+
 rvalue_list *make_rvalue_list(rvalue *rv);
 rvalue_list *append_rvalue_list(rvalue_list *rvals, rvalue *rv);
 
