@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -27,7 +27,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: ResponseTooBigErr.cc 17856 2008-02-02 21:25:59Z pwest $"
+    {"$Id: ResponseTooBigErr.cc 27197 2013-10-01 21:29:54Z jimg $"
     };
 
 #include <string>
