@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -31,10 +31,6 @@
 
 #include "config.h"
 
-static char rcsid[] not_used =
-    { "$Id: SignalHandler.cc 22703 2010-05-11 18:10:01Z jimg $"
-    };
-
 #include <cstdlib>
 
 #include <signal.h>
@@ -86,7 +82,7 @@ SignalHandler::delete_instance()
 }
 
 /** This private method is the adapter between the C-style interface of the
-    signal sub-system and C++'s method interface. This uses the lookup table
+    signal subsystem and C++'s method interface. This uses the lookup table
     to find an instance of EventHandler and calls that instance's
     handle_signal method.
 
@@ -104,6 +100,7 @@ SignalHandler::dispatcher(int signum)
         return;
     else if (old_handler == SIG_DFL) {
         switch (signum) {
+#if 0
 #ifndef WIN32
         case SIGHUP:
         case SIGKILL:
@@ -118,6 +115,11 @@ SignalHandler::dispatcher(int signum)
             // register_handler() should never allow any fiddling with
             // signals other than those listed above.
         default: abort();
+#endif
+        // Calling _exit() or abort() is not a good thing for a library to be
+        // doing. This results in a warning from rpmlint
+        default:
+            throw Error("Signal handler operation on an unsupported signal.");
         }
     }
     else
