@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -36,23 +36,23 @@
 
 #include "config.h"
 
-static char rcsid[] not_used =
-    {"$Id: UInt16.cc 21699 2009-11-05 00:06:01Z jimg $"
-    };
+#include <sstream>
 
-#include "Byte.h"
+#include "Byte.h"           // synonymous with UInt8 and Char
+#include "Int8.h"
 #include "Int16.h"
 #include "UInt16.h"
 #include "Int32.h"
 #include "UInt32.h"
+#include "Int64.h"
+#include "UInt64.h"
 #include "Float32.h"
 #include "Float64.h"
 #include "Str.h"
 #include "Url.h"
-#include "Array.h"
-#include "Structure.h"
-#include "Sequence.h"
-#include "Grid.h"
+
+#include "Marshaller.h"
+#include "UnMarshaller.h"
 
 #include "DDS.h"
 #include "util.h"
@@ -88,7 +88,7 @@ UInt16::UInt16(const string &n, const string &d)
 
 UInt16::UInt16(const UInt16 &copy_from) : BaseType(copy_from)
 {
-    _buf = copy_from._buf;
+    d_buf = copy_from.d_buf;
 }
 
 BaseType *
@@ -105,13 +105,13 @@ UInt16::operator=(const UInt16 &rhs)
 
     dynamic_cast<BaseType &>(*this) = rhs;
 
-    _buf = rhs._buf;
+    d_buf = rhs.d_buf;
 
     return *this;
 }
 
 unsigned int
-UInt16::width()
+UInt16::width(bool)
 {
     return sizeof(dods_uint16);
 }
@@ -132,7 +132,7 @@ UInt16::serialize(ConstraintEvaluator &eval, DDS &dds,
 
     dds.timeout_off();
 
-    m.put_uint16( _buf ) ;
+    m.put_uint16( d_buf ) ;
 
     return true;
 }
@@ -140,7 +140,7 @@ UInt16::serialize(ConstraintEvaluator &eval, DDS &dds,
 bool
 UInt16::deserialize(UnMarshaller &um, DDS *, bool)
 {
-    um.get_uint16( _buf ) ;
+    um.get_uint16( d_buf ) ;
 
     return false;
 }
@@ -156,7 +156,7 @@ UInt16::val2buf(void *val, bool)
         throw InternalErr(__FILE__, __LINE__,
                           "The incoming pointer does not contain any data.");
 
-    _buf = *(dods_uint16 *)val;
+    d_buf = *(dods_uint16 *)val;
 
     return width();
 }
@@ -172,7 +172,7 @@ UInt16::buf2val(void **val)
     if (!*val)
         *val = new dods_uint16;
 
-    *(dods_uint16 *)*val = _buf;
+    *(dods_uint16 *)*val = d_buf;
 
     return width();
 }
@@ -180,40 +180,35 @@ UInt16::buf2val(void **val)
 dods_uint16
 UInt16::value() const
 {
-    return _buf;
+    return d_buf;
 }
 
 bool
 UInt16::set_value(dods_uint16 i)
 {
-    _buf = i;
+    d_buf = i;
     set_read_p(true);
 
     return true;
 }
 
-#if FILE_METHODS
 void
 UInt16::print_val(FILE *out, string space, bool print_decl_p)
 {
-    if (print_decl_p) {
-        print_decl(out, space, false);
-        fprintf(out, " = %u;\n", (unsigned int)_buf) ;
-    }
-    else
-        fprintf(out, "%u", (unsigned int)_buf) ;
+    ostringstream oss;
+    print_val(oss, space, print_decl_p);
+    fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
-#endif
 
 void
 UInt16::print_val(ostream &out, string space, bool print_decl_p)
 {
     if (print_decl_p) {
         print_decl(out, space, false);
-	out << " = " << (unsigned int)_buf << ";\n" ;
+	out << " = " << (unsigned int)d_buf << ";\n" ;
     }
     else
-	out << (unsigned int)_buf ;
+	out << (unsigned int)d_buf ;
 }
 
 bool
@@ -240,29 +235,28 @@ UInt16::ops(BaseType *b, int op)
     }
 
     switch (b->type()) {
-    case dods_byte_c:
-        return rops<dods_uint16, dods_byte, Cmp<dods_uint16, dods_byte> >
-               (_buf, dynamic_cast<Byte *>(b)->_buf, op);
-    case dods_int16_c:
-        return rops<dods_uint16, dods_int16, USCmp<dods_uint16, dods_int16> >
-               (_buf, dynamic_cast<Int16 *>(b)->_buf, op);
-    case dods_uint16_c:
-        return rops<dods_uint16, dods_uint16, Cmp<dods_uint16, dods_uint16> >
-               (_buf, dynamic_cast<UInt16 *>(b)->_buf, op);
-    case dods_int32_c:
-        return rops<dods_uint16, dods_int32, USCmp<dods_uint16, dods_int32> >
-               (_buf, dynamic_cast<Int32 *>(b)->_buf, op);
-    case dods_uint32_c:
-        return rops<dods_uint16, dods_uint32, Cmp<dods_uint16, dods_uint32> >
-               (_buf, dynamic_cast<UInt32 *>(b)->_buf, op);
-    case dods_float32_c:
-        return rops<dods_uint16, dods_float32, Cmp<dods_uint16, dods_float32> >
-               (_buf, dynamic_cast<Float32 *>(b)->_buf, op);
-    case dods_float64_c:
-        return rops<dods_uint16, dods_float64, Cmp<dods_uint16, dods_float64> >
-               (_buf, dynamic_cast<Float64 *>(b)->_buf, op);
-    default:
-        return false;
+        case dods_int8_c:
+            return USCmp<dods_uint16, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
+        case dods_byte_c:
+            return Cmp<dods_uint16, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
+        case dods_int16_c:
+            return USCmp<dods_uint16, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
+        case dods_uint16_c:
+            return Cmp<dods_uint16, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
+        case dods_int32_c:
+            return USCmp<dods_uint16, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
+        case dods_uint32_c:
+            return Cmp<dods_uint16, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
+        case dods_int64_c:
+            return USCmp<dods_uint16, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
+        case dods_uint64_c:
+            return Cmp<dods_uint16, dods_uint64>(op, d_buf, static_cast<UInt64*>(b)->value());
+        case dods_float32_c:
+            return USCmp<dods_uint16, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
+        case dods_float64_c:
+            return USCmp<dods_uint16, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
+        default:
+            return false;
     }
 }
 
@@ -281,7 +275,7 @@ UInt16::dump(ostream &strm) const
     << (void *)this << ")" << endl ;
     DapIndent::Indent() ;
     BaseType::dump(strm) ;
-    strm << DapIndent::LMarg << "value: " << _buf << endl ;
+    strm << DapIndent::LMarg << "value: " << d_buf << endl ;
     DapIndent::UnIndent() ;
 }
 
