@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -49,8 +49,6 @@
 #include "ConstraintEvaluator.h"
 #endif
 
-#define FILE_METHODS 1
-
 namespace libdap
 {
 
@@ -58,20 +56,8 @@ namespace libdap
 
 class UInt16: public BaseType
 {
-    /** This class allows Byte, ..., Float64 access to <tt>_buf</tt> to
-    simplify and speed up the relational operators.
-
-    NB: According to Stroustrup it does not matter where (public, private
-    or protected) friend classes are declared. */
-    friend class Byte;
-    friend class Int16;
-    friend class Int32;
-    friend class UInt32;
-    friend class Float32;
-    friend class Float64;
-
 protected:
-    dods_uint16 _buf;
+    dods_uint16 d_buf;
 
 public:
     UInt16(const string &n);
@@ -85,7 +71,7 @@ public:
 
     virtual BaseType *ptr_duplicate();
 
-    virtual unsigned int width();
+    virtual unsigned int width(bool constrained = false);
 
     virtual bool serialize(ConstraintEvaluator &eval, DDS &dds,
 			   Marshaller &m, bool ce_eval = true);
@@ -96,10 +82,9 @@ public:
 
     virtual dods_uint16 value() const;
     virtual bool set_value(dods_uint16 val);
-#if FILE_METHODS
+
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true);
-#endif
     virtual void print_val(ostream &out, string space = "",
                            bool print_decl_p = true);
 
