@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -78,7 +78,7 @@ namespace libdap
 class Vector: public BaseType
 {
 private:
-    int _length;  // number of elements in the vector
+    int d_length;  // number of elements in the vector
     BaseType *_var;  // base type of the Vector
 
     // _buf was a pointer to void; delete[] complained. 6/4/2001 jhrg
@@ -87,7 +87,7 @@ private:
     vector<BaseType *> _vec; // array for other data
 
     // the number of elements we have allocated memory to store.
-    // This should be either the sizeof(buf)/width() for cardinal data
+    // This should be either the sizeof(buf)/width(bool constrained = false) for cardinal data
     // or the capacity of d_str for strings or capacity of _vec.
     unsigned int _capacity;
 
@@ -95,9 +95,9 @@ protected:
     // This function copies the private members of Vector.
     void _duplicate(const Vector &v);
 
-    bool is_cardinal_type() const;
-    unsigned int create_cardinal_data_buffer_for_type(unsigned int numEltsOfType);
-    void delete_cardinal_data_buffer();
+    bool m_is_cardinal_type() const;
+    unsigned int m_create_cardinal_data_buffer_for_type(unsigned int numEltsOfType);
+    void m_delete_cardinal_data_buffer();
 
     template <class CardType> void set_cardinal_values_internal(const CardType* fromArray, int numElts);
 
@@ -111,6 +111,8 @@ public:
     Vector &operator=(const Vector &rhs);
     virtual BaseType *ptr_duplicate() = 0;
 
+    virtual bool is_dap2_only_type();
+
     virtual void set_name(const std::string& name);
 
     virtual int element_count(bool leaves);
@@ -119,7 +121,7 @@ public:
 
     virtual void set_read_p(bool state);
 
-    virtual unsigned int width();
+    virtual unsigned int width(bool constrained = false);
 
     virtual int length() const;
 
@@ -172,6 +174,15 @@ public:
     virtual void value(dods_float64 *b) const;
     virtual void value(vector<string> &b) const;
 
+    void value(vector<unsigned int> *index, dods_byte *b) const;
+    void value(vector<unsigned int> *index, dods_int16 *b) const;
+    void value(vector<unsigned int> *index, dods_uint16 *b) const;
+    void value(vector<unsigned int> *index, dods_int32 *b) const;
+    void value(vector<unsigned int> *index, dods_uint32 *b) const;
+    void value(vector<unsigned int> *index, dods_float32 *b) const;
+    void value(vector<unsigned int> *index, dods_float64 *b) const;
+    void value(vector<unsigned int> *index, vector<string> &b) const;
+
     virtual void *value();
 
     virtual BaseType *var(const string &name = "", bool exact_match = true,
@@ -180,6 +191,8 @@ public:
     virtual BaseType *var(unsigned int i);
 
     virtual void add_var(BaseType *v, Part p = nil);
+    virtual void add_var_nocopy(BaseType *v, Part p = nil);
+
     virtual bool check_semantics(string &msg, bool all = false);
 
     virtual void dump(ostream &strm) const ;
