@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,19 +54,102 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse dasparse
-#define yylex   daslex
-#define yyerror daserror
-#define yylval  daslval
-#define yychar  daschar
-#define yydebug dasdebug
-#define yynerrs dasnerrs
+#define yyparse         dasparse
+#define yylex           daslex
+#define yyerror         daserror
+#define yylval          daslval
+#define yychar          daschar
+#define yydebug         dasdebug
+#define yynerrs         dasnerrs
 
 
+/* Copy the first part of user declarations.  */
+
+
+/* Line 189 of yacc.c  */
+#line 81 "das.tab.cc"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+/* "%code requires" blocks.  */
+
+/* Line 209 of yacc.c  */
+#line 40 "das.yy"
+
+
+#define YYSTYPE char *
+#define ATTR_STRING_QUOTE_FIX
+
+#include "config.h"
+
+#include <string>
+
+#include <vector>
+
+#include "DAS.h"
+#include "Error.h"
+#include "util.h"
+#include "escaping.h"
+#include "debug.h"
+#include "parser.h"
+#include "util.h"
+  // #include "das.tab.hh"
+
+#ifdef TRACE_NEW
+#include "trace_new.h"
+#endif
+
+#define yylex daslex
+#define yyerror daserror 
+
+using namespace std;
+using namespace libdap ;
+
+// These macros are used to access the `arguments' passed to the parser. A
+// pointer to an error object and a pointer to an integer status variable are
+// passed in to the parser within a structure (which itself is passed as a
+// pointer). Note that the ERROR macro explicitly casts OBJ to an ERROR *. 
+// The parser now throws an exception when it encounters an error. 5/23/2002
+// jhrg 
+
+#define DAS_OBJ(arg) ((DAS *)((parser_arg *)(arg))->_object)
+
+//#define YYPARSE_PARAM arg
+
+extern int das_line_num;	/* defined in das.lex */
+
+
+
+
+/* Line 209 of yacc.c  */
+#line 152 "das.tab.cc"
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -89,70 +171,26 @@
      SCAN_XML = 270
    };
 #endif
-/* Tokens.  */
-#define SCAN_ATTR 258
-#define SCAN_WORD 259
-#define SCAN_ALIAS 260
-#define SCAN_BYTE 261
-#define SCAN_INT16 262
-#define SCAN_UINT16 263
-#define SCAN_INT32 264
-#define SCAN_UINT32 265
-#define SCAN_FLOAT32 266
-#define SCAN_FLOAT64 267
-#define SCAN_STRING 268
-#define SCAN_URL 269
-#define SCAN_XML 270
 
 
 
-
-/* Copy the first part of user declarations.  */
-#line 40 "das.y"
-
-
-#define YYSTYPE char *
-#define ATTR_STRING_QUOTE_FIX
-
-#include "config.h"
-
-static char rcsid[] not_used = {"$Id: das.y 21577 2009-10-02 16:12:17Z jimg $"};
-
-#include <string>
-
-#include <vector>
-
-#include "DAS.h"
-#include "Error.h"
-#include "util.h"
-#include "escaping.h"
-#include "debug.h"
-#include "parser.h"
-#include "util.h"
-#include "das.tab.hh"
-
-#ifdef TRACE_NEW
-#include "trace_new.h"
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef int YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
 #endif
 
-#define yylex daslex
-#define yyerror daserror 
 
-using namespace std;
-using namespace libdap ;
+/* Copy the second part of user declarations.  */
 
-// These macros are used to access the `arguments' passed to the parser. A
-// pointer to an error object and a pointer to an integer status variable are
-// passed in to the parser within a structure (which itself is passed as a
-// pointer). Note that the ERROR macro explicitly casts OBJ to an ERROR *. 
-// The parser now throws an exception when it encounters an error. 5/23/2002
-// jhrg 
 
-#define DAS_OBJ(arg) ((DAS *)((parser_arg *)(arg))->_object)
+/* Line 264 of yacc.c  */
+#line 190 "das.tab.cc"
+/* Unqualified %code blocks.  */
 
-#define YYPARSE_PARAM arg
-
-extern int das_line_num;	/* defined in das.lex */
+/* Line 265 of yacc.c  */
+#line 85 "das.yy"
 
 // No global static objects. We go through this every so often, I guess I
 // should learn... 1/24/2000 jhrg
@@ -182,7 +220,7 @@ Check that the URL is correct.";
 typedef int checker(const char *);
 
 int daslex(void);
-static void daserror(char *s);
+static void daserror(parser_arg *arg, const string &s /*char *s*/);
 static void add_attribute(const string &type, const string &name, 
 			  const string &value, checker *chk) throw (Error);
 static void add_alias(AttrTable *das, AttrTable *current, const string &name, 
@@ -193,38 +231,9 @@ static void add_bad_attribute(AttrTable *attr, const string &type,
 
 
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
 
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef int YYSTYPE;
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
-# define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
-#endif
-
-
-
-/* Copy the second part of user declarations.  */
-
-
-/* Line 216 of yacc.c.  */
-#line 228 "das.tab.cc"
+/* Line 265 of yacc.c  */
+#line 237 "das.tab.cc"
 
 #ifdef short
 # undef short
@@ -299,14 +308,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -387,9 +396,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -423,12 +432,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -537,15 +546,15 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   185,   185,   185,   202,   203,   207,   208,   214,   215,
-     216,   219,   221,   222,   221,   225,   226,   225,   229,   230,
-     229,   233,   234,   233,   237,   238,   237,   241,   242,   241,
-     245,   246,   245,   249,   250,   249,   253,   254,   253,   257,
-     258,   257,   262,   282,   261,   290,   289,   295,   299,   305,
-     309,   315,   319,   325,   329,   335,   339,   345,   349,   355,
-     359,   365,   370,   377,   381,   387,   403,   406,   409,   412,
-     412,   412,   412,   412,   413,   413,   413,   413,   414,   414,
-     414,   414,   418,   422,   417
+       0,   194,   194,   194,   211,   212,   216,   217,   223,   224,
+     225,   228,   230,   231,   230,   234,   235,   234,   238,   239,
+     238,   242,   243,   242,   246,   247,   246,   250,   251,   250,
+     254,   255,   254,   258,   259,   258,   262,   263,   262,   266,
+     267,   266,   271,   291,   270,   299,   298,   304,   308,   314,
+     318,   324,   328,   334,   338,   344,   348,   354,   358,   364,
+     368,   374,   379,   386,   390,   396,   412,   415,   418,   421,
+     421,   421,   421,   421,   422,   422,   422,   422,   423,   423,
+     423,   423,   427,   431,   426
 };
 #endif
 
@@ -557,12 +566,13 @@ static const char *const yytname[] =
   "$end", "error", "$undefined", "SCAN_ATTR", "SCAN_WORD", "SCAN_ALIAS",
   "SCAN_BYTE", "SCAN_INT16", "SCAN_UINT16", "SCAN_INT32", "SCAN_UINT32",
   "SCAN_FLOAT32", "SCAN_FLOAT64", "SCAN_STRING", "SCAN_URL", "SCAN_XML",
-  "'{'", "'}'", "';'", "','", "$accept", "attr_start", "@1", "attributes",
-  "attribute", "attr_list", "attr_tuple", "@2", "@3", "@4", "@5", "@6",
-  "@7", "@8", "@9", "@10", "@11", "@12", "@13", "@14", "@15", "@16", "@17",
-  "@18", "@19", "@20", "@21", "@22", "@23", "@24", "bytes", "int16",
-  "uint16", "int32", "uint32", "float32", "float64", "strs", "urls", "xml",
-  "url", "str_or_id", "float_or_int", "name", "alias", "@25", "@26", 0
+  "'{'", "'}'", "';'", "','", "$accept", "attr_start", "$@1", "attributes",
+  "attribute", "attr_list", "attr_tuple", "$@2", "$@3", "$@4", "$@5",
+  "$@6", "$@7", "$@8", "$@9", "$@10", "$@11", "$@12", "$@13", "$@14",
+  "$@15", "$@16", "$@17", "$@18", "$@19", "$@20", "$@21", "$@22", "$@23",
+  "$@24", "bytes", "int16", "uint16", "int32", "uint32", "float32",
+  "float64", "strs", "urls", "xml", "url", "str_or_id", "float_or_int",
+  "name", "alias", "$@25", "$@26", 0
 };
 #endif
 
@@ -753,7 +763,7 @@ do								\
     }								\
   else								\
     {								\
-      yyerror (YY_("syntax error: cannot back up")); \
+      yyerror (arg, YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
 while (YYID (0))
@@ -833,7 +843,7 @@ do {									  \
     {									  \
       YYFPRINTF (stderr, "%s ", Title);					  \
       yy_symbol_print (stderr,						  \
-		  Type, Value); \
+		  Type, Value, arg); \
       YYFPRINTF (stderr, "\n");						  \
     }									  \
 } while (YYID (0))
@@ -847,17 +857,19 @@ do {									  \
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 #else
 static void
-yy_symbol_value_print (yyoutput, yytype, yyvaluep)
+yy_symbol_value_print (yyoutput, yytype, yyvaluep, arg)
     FILE *yyoutput;
     int yytype;
     YYSTYPE const * const yyvaluep;
+    parser_arg *arg;
 #endif
 {
   if (!yyvaluep)
     return;
+  YYUSE (arg);
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
     YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
@@ -879,13 +891,14 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 #else
 static void
-yy_symbol_print (yyoutput, yytype, yyvaluep)
+yy_symbol_print (yyoutput, yytype, yyvaluep, arg)
     FILE *yyoutput;
     int yytype;
     YYSTYPE const * const yyvaluep;
+    parser_arg *arg;
 #endif
 {
   if (yytype < YYNTOKENS)
@@ -893,7 +906,7 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
+  yy_symbol_value_print (yyoutput, yytype, yyvaluep, arg);
   YYFPRINTF (yyoutput, ")");
 }
 
@@ -905,17 +918,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -933,12 +949,13 @@ do {								\
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
+yy_reduce_print (YYSTYPE *yyvsp, int yyrule, parser_arg *arg)
 #else
 static void
-yy_reduce_print (yyvsp, yyrule)
+yy_reduce_print (yyvsp, yyrule, arg)
     YYSTYPE *yyvsp;
     int yyrule;
+    parser_arg *arg;
 #endif
 {
   int yynrhs = yyr2[yyrule];
@@ -949,18 +966,18 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
-		       		       );
-      fprintf (stderr, "\n");
+		       		       , arg);
+      YYFPRINTF (stderr, "\n");
     }
 }
 
 # define YY_REDUCE_PRINT(Rule)		\
 do {					\
   if (yydebug)				\
-    yy_reduce_print (yyvsp, Rule); \
+    yy_reduce_print (yyvsp, Rule, arg); \
 } while (YYID (0))
 
 /* Nonzero means print parse trace.  It is left uninitialized so that
@@ -1211,16 +1228,18 @@ yysyntax_error (char *yyresult, int yystate, int yychar)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, parser_arg *arg)
 #else
 static void
-yydestruct (yymsg, yytype, yyvaluep)
+yydestruct (yymsg, yytype, yyvaluep, arg)
     const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
+    parser_arg *arg;
 #endif
 {
   YYUSE (yyvaluep);
+  YYUSE (arg);
 
   if (!yymsg)
     yymsg = "Deleting";
@@ -1233,10 +1252,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1245,18 +1262,17 @@ int yyparse ();
 #endif
 #else /* ! YYPARSE_PARAM */
 #if defined __STDC__ || defined __cplusplus
-int yyparse (void);
+int yyparse (parser_arg *arg);
 #else
 int yyparse ();
 #endif
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1264,9 +1280,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1282,22 +1298,47 @@ yyparse (YYPARSE_PARAM)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 int
-yyparse (void)
+yyparse (parser_arg *arg)
 #else
 int
-yyparse ()
-
+yyparse (arg)
+    parser_arg *arg;
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1305,51 +1346,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1379,7 +1397,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1387,7 +1404,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1410,9 +1426,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1423,7 +1438,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1433,6 +1447,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1441,16 +1458,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1482,20 +1499,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1535,7 +1548,9 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 185 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 194 "das.yy"
     {
 		name = new string();
 		type = new string();
@@ -1547,7 +1562,9 @@ yyreduce:
     break;
 
   case 3:
-#line 194 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 203 "das.yy"
     {
 		POP;	// pop the DAS/AttrTable before stack's dtor
 		delete name;
@@ -1557,114 +1574,158 @@ yyreduce:
     break;
 
   case 7:
-#line 209 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 218 "das.yy"
     {
 		    parse_error((parser_arg *)arg, NO_DAS_MSG, das_line_num);
 		;}
     break;
 
   case 12:
-#line 221 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 230 "das.yy"
     { save_str(*type, "Byte", das_line_num); ;}
     break;
 
   case 13:
-#line 222 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 231 "das.yy"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 15:
-#line 225 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 234 "das.yy"
     { save_str(*type, "Int16", das_line_num); ;}
     break;
 
   case 16:
-#line 226 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 235 "das.yy"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 18:
-#line 229 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 238 "das.yy"
     { save_str(*type, "UInt16", das_line_num); ;}
     break;
 
   case 19:
-#line 230 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 239 "das.yy"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 21:
-#line 233 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 242 "das.yy"
     { save_str(*type, "Int32", das_line_num); ;}
     break;
 
   case 22:
-#line 234 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 243 "das.yy"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 24:
-#line 237 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 246 "das.yy"
     { save_str(*type, "UInt32", das_line_num); ;}
     break;
 
   case 25:
-#line 238 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 247 "das.yy"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 27:
-#line 241 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 250 "das.yy"
     { save_str(*type, "Float32", das_line_num); ;}
     break;
 
   case 28:
-#line 242 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 251 "das.yy"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 30:
-#line 245 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 254 "das.yy"
     { save_str(*type, "Float64", das_line_num); ;}
     break;
 
   case 31:
-#line 246 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 255 "das.yy"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 33:
-#line 249 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 258 "das.yy"
     { *type = "String"; ;}
     break;
 
   case 34:
-#line 250 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 259 "das.yy"
     { *name = (yyvsp[(3) - (3)]); ;}
     break;
 
   case 36:
-#line 253 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 262 "das.yy"
     { *type = "Url"; ;}
     break;
 
   case 37:
-#line 254 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 263 "das.yy"
     { *name = (yyvsp[(3) - (3)]); ;}
     break;
 
   case 39:
-#line 257 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 266 "das.yy"
     { *type = "OtherXML"; ;}
     break;
 
   case 40:
-#line 258 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 267 "das.yy"
     { *name = (yyvsp[(3) - (3)]); ;}
     break;
 
   case 42:
-#line 262 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 271 "das.yy"
     {
 		    DBG(cerr << "Processing ID: " << (yyvsp[(1) - (1)]) << endl);
 		    
@@ -1687,7 +1748,9 @@ yyreduce:
     break;
 
   case 43:
-#line 282 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 291 "das.yy"
     {
 		    /* pop top of stack; store in attr_tab */
 		    DBG(cerr << " Popped attr_tab: " << TOP_OF_STACK << endl);
@@ -1696,112 +1759,144 @@ yyreduce:
     break;
 
   case 45:
-#line 290 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 299 "das.yy"
     { 
 		    parse_error(ATTR_TUPLE_MSG, das_line_num, (yyvsp[(1) - (1)]));
 		;}
     break;
 
   case 47:
-#line 296 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 305 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_byte);
 		;}
     break;
 
   case 48:
-#line 300 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 309 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_byte);
 		;}
     break;
 
   case 49:
-#line 306 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 315 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_int16);
 		;}
     break;
 
   case 50:
-#line 310 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 319 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_int16);
 		;}
     break;
 
   case 51:
-#line 316 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 325 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_uint16);
 		;}
     break;
 
   case 52:
-#line 320 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 329 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_uint16);
 		;}
     break;
 
   case 53:
-#line 326 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 335 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_int32);
 		;}
     break;
 
   case 54:
-#line 330 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 339 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_int32);
 		;}
     break;
 
   case 55:
-#line 336 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 345 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_uint32);
 		;}
     break;
 
   case 56:
-#line 340 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 349 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_uint32);
 		;}
     break;
 
   case 57:
-#line 346 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 355 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_float32);
 		;}
     break;
 
   case 58:
-#line 350 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 359 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_float32);
 		;}
     break;
 
   case 59:
-#line 356 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 365 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_float64);
 		;}
     break;
 
   case 60:
-#line 360 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 369 "das.yy"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_float64);
 		;}
     break;
 
   case 61:
-#line 366 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 375 "das.yy"
     {
 		    string attr = remove_quotes((yyvsp[(1) - (1)]));
 		    add_attribute(*type, *name, attr, 0);
@@ -1809,7 +1904,9 @@ yyreduce:
     break;
 
   case 62:
-#line 371 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 380 "das.yy"
     {
 		    string attr = remove_quotes((yyvsp[(3) - (3)]));
 		    add_attribute(*type, *name, attr, 0);
@@ -1817,21 +1914,27 @@ yyreduce:
     break;
 
   case 63:
-#line 378 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 387 "das.yy"
     {
                     add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_url);
                 ;}
     break;
 
   case 64:
-#line 382 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 391 "das.yy"
     {
                     add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_url);
                 ;}
     break;
 
   case 65:
-#line 388 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 397 "das.yy"
     {
                     // XML must be quoted in the DAS but the quotes are an
                     // artifact of the DAS syntax so they are not part of the
@@ -1848,14 +1951,18 @@ yyreduce:
     break;
 
   case 82:
-#line 418 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 427 "das.yy"
     { 
 		    *name = (yyvsp[(2) - (2)]);
 		;}
     break;
 
   case 83:
-#line 422 "das.y"
+
+/* Line 1455 of yacc.c  */
+#line 431 "das.yy"
     {
 		    add_alias( DAS_OBJ(arg)->get_top_level_attributes(),
 		               TOP_OF_STACK, *name, string((yyvsp[(4) - (4)])) ) ;
@@ -1863,8 +1970,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1868 "das.tab.cc"
+
+/* Line 1455 of yacc.c  */
+#line 1976 "das.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1875,7 +1983,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1900,7 +2007,7 @@ yyerrlab:
     {
       ++yynerrs;
 #if ! YYERROR_VERBOSE
-      yyerror (YY_("syntax error"));
+      yyerror (arg, YY_("syntax error"));
 #else
       {
 	YYSIZE_T yysize = yysyntax_error (0, yystate, yychar);
@@ -1924,11 +2031,11 @@ yyerrlab:
 	if (0 < yysize && yysize <= yymsg_alloc)
 	  {
 	    (void) yysyntax_error (yymsg, yystate, yychar);
-	    yyerror (yymsg);
+	    yyerror (arg, yymsg);
 	  }
 	else
 	  {
-	    yyerror (YY_("syntax error"));
+	    yyerror (arg, YY_("syntax error"));
 	    if (yysize != 0)
 	      goto yyexhaustedlab;
 	  }
@@ -1940,7 +2047,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1952,12 +2059,12 @@ yyerrlab:
       else
 	{
 	  yydestruct ("Error: discarding",
-		      yytoken, &yylval);
+		      yytoken, &yylval, arg);
 	  yychar = YYEMPTY;
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2008,15 +2115,12 @@ yyerrlab1:
 
 
       yydestruct ("Error: popping",
-		  yystos[yystate], yyvsp);
+		  yystos[yystate], yyvsp, arg);
       YYPOPSTACK (1);
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2041,20 +2145,20 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
 yyexhaustedlab:
-  yyerror (YY_("memory exhausted"));
+  yyerror (arg, YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
-		 yytoken, &yylval);
+		 yytoken, &yylval, arg);
   /* Do not reclaim the symbols of the rule which action triggered
      this YYABORT or YYACCEPT.  */
   YYPOPSTACK (yylen);
@@ -2062,7 +2166,7 @@ yyreturn:
   while (yyssp != yyss)
     {
       yydestruct ("Cleanup: popping",
-		  yystos[*yyssp], yyvsp);
+		  yystos[*yyssp], yyvsp, arg);
       YYPOPSTACK (1);
     }
 #ifndef yyoverflow
@@ -2078,14 +2182,16 @@ yyreturn:
 }
 
 
-#line 429 "das.y"
+
+/* Line 1675 of yacc.c  */
+#line 438 "das.yy"
 
 
 // This function is required for linking, but DODS uses its own error
 // reporting mechanism.
 
 static void
-daserror(char *)
+daserror(parser_arg *, const string &)
 {
 }
 
