@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,72 +54,57 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse ddsparse
-#define yylex   ddslex
-#define yyerror ddserror
-#define yylval  ddslval
-#define yychar  ddschar
-#define yydebug ddsdebug
-#define yynerrs ddsnerrs
-
-
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     SCAN_WORD = 258,
-     SCAN_DATASET = 259,
-     SCAN_LIST = 260,
-     SCAN_SEQUENCE = 261,
-     SCAN_STRUCTURE = 262,
-     SCAN_FUNCTION = 263,
-     SCAN_GRID = 264,
-     SCAN_BYTE = 265,
-     SCAN_INT16 = 266,
-     SCAN_UINT16 = 267,
-     SCAN_INT32 = 268,
-     SCAN_UINT32 = 269,
-     SCAN_FLOAT32 = 270,
-     SCAN_FLOAT64 = 271,
-     SCAN_STRING = 272,
-     SCAN_URL = 273
-   };
-#endif
-/* Tokens.  */
-#define SCAN_WORD 258
-#define SCAN_DATASET 259
-#define SCAN_LIST 260
-#define SCAN_SEQUENCE 261
-#define SCAN_STRUCTURE 262
-#define SCAN_FUNCTION 263
-#define SCAN_GRID 264
-#define SCAN_BYTE 265
-#define SCAN_INT16 266
-#define SCAN_UINT16 267
-#define SCAN_INT32 268
-#define SCAN_UINT32 269
-#define SCAN_FLOAT32 270
-#define SCAN_FLOAT64 271
-#define SCAN_STRING 272
-#define SCAN_URL 273
-
-
+#define yyparse         ddsparse
+#define yylex           ddslex
+#define yyerror         ddserror
+#define yylval          ddslval
+#define yychar          ddschar
+#define yydebug         ddsdebug
+#define yynerrs         ddsnerrs
 
 
 /* Copy the first part of user declarations.  */
-#line 47 "dds.y"
+
+
+/* Line 189 of yacc.c  */
+#line 81 "dds.tab.cc"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+/* "%code requires" blocks.  */
+
+/* Line 209 of yacc.c  */
+#line 47 "dds.yy"
 
 
 #include "config_dap.h"
 
-static char rcsid[] not_used = {"$Id: dds.y 21577 2009-10-02 16:12:17Z jimg $"};
-
 #include <cstring>
 #include <cassert>
 #include <iostream>
@@ -157,10 +141,75 @@ using namespace libdap;
 // exceptions. 5/22/2002 jhrg
 #define DDS_OBJ(arg) ((DDS *)((parser_arg *)(arg))->_object)
 
-#define YYPARSE_PARAM arg
+// #define YYPARSE_PARAM arg
 
 extern int dds_line_num;	/* defined in dds.lex */
 
+
+
+
+/* Line 209 of yacc.c  */
+#line 153 "dds.tab.cc"
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     SCAN_WORD = 258,
+     SCAN_DATASET = 259,
+     SCAN_LIST = 260,
+     SCAN_SEQUENCE = 261,
+     SCAN_STRUCTURE = 262,
+     SCAN_FUNCTION = 263,
+     SCAN_GRID = 264,
+     SCAN_BYTE = 265,
+     SCAN_INT16 = 266,
+     SCAN_UINT16 = 267,
+     SCAN_INT32 = 268,
+     SCAN_UINT32 = 269,
+     SCAN_FLOAT32 = 270,
+     SCAN_FLOAT64 = 271,
+     SCAN_STRING = 272,
+     SCAN_URL = 273
+   };
+#endif
+
+
+
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
+{
+
+/* Line 214 of yacc.c  */
+#line 131 "dds.yy"
+
+    bool boolean;
+    char word[ID_MAX];
+
+
+
+/* Line 214 of yacc.c  */
+#line 195 "dds.tab.cc"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
+#endif
+
+
+/* Copy the second part of user declarations.  */
+
+
+/* Line 264 of yacc.c  */
+#line 207 "dds.tab.cc"
+/* Unqualified %code blocks.  */
+
+/* Line 265 of yacc.c  */
+#line 93 "dds.yy"
+
+
 // No global static objects in the dap library! 1/24/2000 jhrg
 static stack<BaseType *> *ctor;
 static BaseType *current;
@@ -176,9 +225,9 @@ static const char *BAD_DECLARATION =
 (e.g., Int32 i;). Make sure that the variable name is not the name\n\
 of a datatype and that the Array: and Maps: sections of a Grid are\n\
 labeled properly.";
- 
+
 int ddslex();
-void ddserror(char *s);
+void ddserror(parser_arg *arg, const string &s /*char *s*/);
 void error_exit_cleanup();
 void add_entry(DDS &table, stack<BaseType *> **ctor, BaseType **current, 
 	       Part p);
@@ -187,46 +236,9 @@ void invalid_declaration(parser_arg *arg, string semantic_err_msg,
 
 
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
 
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
-#line 121 "dds.y"
-{
-    bool boolean;
-    char word[ID_MAX];
-}
-/* Line 187 of yacc.c.  */
-#line 217 "dds.tab.cc"
-	YYSTYPE;
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
-# define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
-#endif
-
-
-
-/* Copy the second part of user declarations.  */
-
-
-/* Line 216 of yacc.c.  */
-#line 230 "dds.tab.cc"
+/* Line 265 of yacc.c  */
+#line 242 "dds.tab.cc"
 
 #ifdef short
 # undef short
@@ -301,14 +313,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -389,9 +401,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -425,12 +437,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -528,12 +540,12 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   150,   150,   150,   160,   161,   164,   168,   178,   182,
-     183,   190,   213,   212,   233,   232,   253,   265,   277,   252,
-     298,   309,   315,   321,   327,   328,   329,   330,   331,   332,
-     333,   334,   335,   338,   339,   342,   342,   342,   342,   342,
-     343,   343,   343,   343,   344,   344,   344,   344,   345,   348,
-     372,   376,   371,   403,   414,   415,   416
+       0,   160,   160,   160,   170,   171,   174,   178,   188,   192,
+     193,   200,   223,   222,   243,   242,   263,   275,   287,   262,
+     308,   319,   325,   331,   337,   338,   339,   340,   341,   342,
+     343,   344,   345,   348,   349,   352,   352,   352,   352,   352,
+     353,   353,   353,   353,   354,   354,   354,   354,   355,   358,
+     382,   386,   381,   413,   424,   425,   426
 };
 #endif
 
@@ -546,10 +558,10 @@ static const char *const yytname[] =
   "SCAN_SEQUENCE", "SCAN_STRUCTURE", "SCAN_FUNCTION", "SCAN_GRID",
   "SCAN_BYTE", "SCAN_INT16", "SCAN_UINT16", "SCAN_INT32", "SCAN_UINT32",
   "SCAN_FLOAT32", "SCAN_FLOAT64", "SCAN_STRING", "SCAN_URL", "'{'", "'}'",
-  "';'", "':'", "'['", "']'", "'='", "$accept", "start", "@1", "datasets",
-  "dataset", "declarations", "declaration", "@2", "@3", "@4", "@5", "@6",
-  "structure", "sequence", "grid", "base_type", "var", "var_name",
-  "array_decl", "@7", "@8", "name", 0
+  "';'", "':'", "'['", "']'", "'='", "$accept", "start", "$@1", "datasets",
+  "dataset", "declarations", "declaration", "$@2", "$@3", "$@4", "$@5",
+  "$@6", "structure", "sequence", "grid", "base_type", "var", "var_name",
+  "array_decl", "$@7", "$@8", "name", 0
 };
 #endif
 
@@ -732,7 +744,7 @@ do								\
     }								\
   else								\
     {								\
-      yyerror (YY_("syntax error: cannot back up")); \
+      yyerror (arg, YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
 while (YYID (0))
@@ -812,7 +824,7 @@ do {									  \
     {									  \
       YYFPRINTF (stderr, "%s ", Title);					  \
       yy_symbol_print (stderr,						  \
-		  Type, Value); \
+		  Type, Value, arg); \
       YYFPRINTF (stderr, "\n");						  \
     }									  \
 } while (YYID (0))
@@ -826,17 +838,19 @@ do {									  \
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 #else
 static void
-yy_symbol_value_print (yyoutput, yytype, yyvaluep)
+yy_symbol_value_print (yyoutput, yytype, yyvaluep, arg)
     FILE *yyoutput;
     int yytype;
     YYSTYPE const * const yyvaluep;
+    parser_arg *arg;
 #endif
 {
   if (!yyvaluep)
     return;
+  YYUSE (arg);
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
     YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
@@ -858,13 +872,14 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, parser_arg *arg)
 #else
 static void
-yy_symbol_print (yyoutput, yytype, yyvaluep)
+yy_symbol_print (yyoutput, yytype, yyvaluep, arg)
     FILE *yyoutput;
     int yytype;
     YYSTYPE const * const yyvaluep;
+    parser_arg *arg;
 #endif
 {
   if (yytype < YYNTOKENS)
@@ -872,7 +887,7 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
+  yy_symbol_value_print (yyoutput, yytype, yyvaluep, arg);
   YYFPRINTF (yyoutput, ")");
 }
 
@@ -884,17 +899,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -912,12 +930,13 @@ do {								\
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_reduce_print (YYSTYPE *yyvsp, int yyrule)
+yy_reduce_print (YYSTYPE *yyvsp, int yyrule, parser_arg *arg)
 #else
 static void
-yy_reduce_print (yyvsp, yyrule)
+yy_reduce_print (yyvsp, yyrule, arg)
     YYSTYPE *yyvsp;
     int yyrule;
+    parser_arg *arg;
 #endif
 {
   int yynrhs = yyr2[yyrule];
@@ -928,18 +947,18 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
-		       		       );
-      fprintf (stderr, "\n");
+		       		       , arg);
+      YYFPRINTF (stderr, "\n");
     }
 }
 
 # define YY_REDUCE_PRINT(Rule)		\
 do {					\
   if (yydebug)				\
-    yy_reduce_print (yyvsp, Rule); \
+    yy_reduce_print (yyvsp, Rule, arg); \
 } while (YYID (0))
 
 /* Nonzero means print parse trace.  It is left uninitialized so that
@@ -1190,16 +1209,18 @@ yysyntax_error (char *yyresult, int yystate, int yychar)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, parser_arg *arg)
 #else
 static void
-yydestruct (yymsg, yytype, yyvaluep)
+yydestruct (yymsg, yytype, yyvaluep, arg)
     const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
+    parser_arg *arg;
 #endif
 {
   YYUSE (yyvaluep);
+  YYUSE (arg);
 
   if (!yymsg)
     yymsg = "Deleting";
@@ -1212,10 +1233,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1224,18 +1243,17 @@ int yyparse ();
 #endif
 #else /* ! YYPARSE_PARAM */
 #if defined __STDC__ || defined __cplusplus
-int yyparse (void);
+int yyparse (parser_arg *arg);
 #else
 int yyparse ();
 #endif
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1243,9 +1261,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1261,22 +1279,47 @@ yyparse (YYPARSE_PARAM)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 int
-yyparse (void)
+yyparse (parser_arg *arg)
 #else
 int
-yyparse ()
-
+yyparse (arg)
+    parser_arg *arg;
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1284,51 +1327,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1358,7 +1378,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1366,7 +1385,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1389,9 +1407,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1402,7 +1419,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1412,6 +1428,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1420,16 +1439,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1461,20 +1480,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1514,7 +1529,9 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 150 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 160 "dds.yy"
     {
 		    /* On entry to the parser, make the BaseType stack. */
 		    ctor = new stack<BaseType *>;
@@ -1522,21 +1539,27 @@ yyreduce:
     break;
 
   case 3:
-#line 155 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 165 "dds.yy"
     {
 		    delete ctor; ctor = 0;
 		;}
     break;
 
   case 6:
-#line 165 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 175 "dds.yy"
     {
 		    (yyval.boolean) = (yyvsp[(3) - (6)].boolean) && (yyvsp[(5) - (6)].word);
 		;}
     break;
 
   case 7:
-#line 169 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 179 "dds.yy"
     {
 		    parse_error((parser_arg *)arg, NO_DDS_MSG,
  				dds_line_num, (yyvsp[(1) - (1)].word));
@@ -1546,24 +1569,32 @@ yyreduce:
     break;
 
   case 8:
-#line 178 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 188 "dds.yy"
     {
 		    (yyval.boolean) = true;
 		;}
     break;
 
   case 9:
-#line 182 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 192 "dds.yy"
     { (yyval.boolean) = true; ;}
     break;
 
   case 10:
-#line 183 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 193 "dds.yy"
     { (yyval.boolean) = true; ;}
     break;
 
   case 11:
-#line 191 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 201 "dds.yy"
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1587,7 +1618,9 @@ yyreduce:
     break;
 
   case 12:
-#line 213 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 223 "dds.yy"
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
@@ -1596,7 +1629,9 @@ yyreduce:
     break;
 
   case 13:
-#line 219 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 229 "dds.yy"
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg))
@@ -1612,7 +1647,9 @@ yyreduce:
     break;
 
   case 14:
-#line 233 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 243 "dds.yy"
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
@@ -1621,7 +1658,9 @@ yyreduce:
     break;
 
   case 15:
-#line 239 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 249 "dds.yy"
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg))
@@ -1637,7 +1676,9 @@ yyreduce:
     break;
 
   case 16:
-#line 253 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 263 "dds.yy"
     { 
 		    if (is_keyword(string((yyvsp[(3) - (4)].word)), "array"))
 			part = array; 
@@ -1652,7 +1693,9 @@ yyreduce:
     break;
 
   case 17:
-#line 265 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 275 "dds.yy"
     { 
 		    if (is_keyword(string((yyvsp[(7) - (8)].word)), "maps"))
 			part = maps; 
@@ -1667,7 +1710,9 @@ yyreduce:
     break;
 
   case 18:
-#line 277 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 287 "dds.yy"
     {
 		    if( current ) delete current ;
 		    current = ctor->top(); 
@@ -1676,7 +1721,9 @@ yyreduce:
     break;
 
   case 19:
-#line 283 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 293 "dds.yy"
     {
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1694,7 +1741,9 @@ yyreduce:
     break;
 
   case 20:
-#line 299 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 309 "dds.yy"
     {
 		    ostringstream msg;
 		    msg << BAD_DECLARATION;
@@ -1705,78 +1754,106 @@ yyreduce:
     break;
 
   case 21:
-#line 310 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 320 "dds.yy"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewStructure()); 
 		;}
     break;
 
   case 22:
-#line 316 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 326 "dds.yy"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewSequence()); 
 		;}
     break;
 
   case 23:
-#line 322 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 332 "dds.yy"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewGrid()); 
 		;}
     break;
 
   case 24:
-#line 327 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 337 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewByte(); ;}
     break;
 
   case 25:
-#line 328 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 338 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt16(); ;}
     break;
 
   case 26:
-#line 329 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 339 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt16(); ;}
     break;
 
   case 27:
-#line 330 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 340 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt32(); ;}
     break;
 
   case 28:
-#line 331 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 341 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt32(); ;}
     break;
 
   case 29:
-#line 332 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 342 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat32(); ;}
     break;
 
   case 30:
-#line 333 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 343 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat64(); ;}
     break;
 
   case 31:
-#line 334 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 344 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewStr(); ;}
     break;
 
   case 32:
-#line 335 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 345 "dds.yy"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUrl(); ;}
     break;
 
   case 33:
-#line 338 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 348 "dds.yy"
     { current->set_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 49:
-#line 349 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 359 "dds.yy"
     { 
 		     if (!check_int32((yyvsp[(2) - (3)].word))) {
 			 string msg = "In the dataset descriptor object:\n";
@@ -1801,14 +1878,18 @@ yyreduce:
     break;
 
   case 50:
-#line 372 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 382 "dds.yy"
     {
 		     id = new string((yyvsp[(2) - (2)].word));
 		 ;}
     break;
 
   case 51:
-#line 376 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 386 "dds.yy"
     { 
 		     if (!check_int32((yyvsp[(5) - (5)].word))) {
 			 string msg = "In the dataset descriptor object:\n";
@@ -1834,14 +1915,18 @@ yyreduce:
     break;
 
   case 52:
-#line 399 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 409 "dds.yy"
     {
 		     (yyval.boolean) = true;
 		 ;}
     break;
 
   case 53:
-#line 404 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 414 "dds.yy"
     {
 		     ostringstream msg;
 		     msg << "In the dataset descriptor object:" << endl
@@ -1853,17 +1938,23 @@ yyreduce:
     break;
 
   case 54:
-#line 414 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 424 "dds.yy"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 55:
-#line 415 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 425 "dds.yy"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 56:
-#line 417 "dds.y"
+
+/* Line 1455 of yacc.c  */
+#line 427 "dds.yy"
     {
 		  ostringstream msg;
 		  msg << "Error parsing the dataset name." << endl
@@ -1875,8 +1966,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1880 "dds.tab.cc"
+
+/* Line 1455 of yacc.c  */
+#line 1972 "dds.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1887,7 +1979,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1912,7 +2003,7 @@ yyerrlab:
     {
       ++yynerrs;
 #if ! YYERROR_VERBOSE
-      yyerror (YY_("syntax error"));
+      yyerror (arg, YY_("syntax error"));
 #else
       {
 	YYSIZE_T yysize = yysyntax_error (0, yystate, yychar);
@@ -1936,11 +2027,11 @@ yyerrlab:
 	if (0 < yysize && yysize <= yymsg_alloc)
 	  {
 	    (void) yysyntax_error (yymsg, yystate, yychar);
-	    yyerror (yymsg);
+	    yyerror (arg, yymsg);
 	  }
 	else
 	  {
-	    yyerror (YY_("syntax error"));
+	    yyerror (arg, YY_("syntax error"));
 	    if (yysize != 0)
 	      goto yyexhaustedlab;
 	  }
@@ -1952,7 +2043,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1964,12 +2055,12 @@ yyerrlab:
       else
 	{
 	  yydestruct ("Error: discarding",
-		      yytoken, &yylval);
+		      yytoken, &yylval, arg);
 	  yychar = YYEMPTY;
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2020,15 +2111,12 @@ yyerrlab1:
 
 
       yydestruct ("Error: popping",
-		  yystos[yystate], yyvsp);
+		  yystos[yystate], yyvsp, arg);
       YYPOPSTACK (1);
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2053,20 +2141,20 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
 yyexhaustedlab:
-  yyerror (YY_("memory exhausted"));
+  yyerror (arg, YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
-		 yytoken, &yylval);
+		 yytoken, &yylval, arg);
   /* Do not reclaim the symbols of the rule which action triggered
      this YYABORT or YYACCEPT.  */
   YYPOPSTACK (yylen);
@@ -2074,7 +2162,7 @@ yyreturn:
   while (yyssp != yyss)
     {
       yydestruct ("Cleanup: popping",
-		  yystos[*yyssp], yyvsp);
+		  yystos[*yyssp], yyvsp, arg);
       YYPOPSTACK (1);
     }
 #ifndef yyoverflow
@@ -2090,87 +2178,88 @@ yyreturn:
 }
 
 
-#line 427 "dds.y"
+
+/* Line 1675 of yacc.c  */
+#line 437 "dds.yy"
 
 
 /* 
-   This function must be defined. However, use the error reporting code in
-   parser-utils.cc.
-*/
-
-void 
-ddserror(char *)
-{
-}
-
-/*
-  Error clean up. Call this before calling YYBORT. Don't call this on a
-  normal exit.
-*/
+ This function must be defined. However, use the error reporting code in
+ parser-utils.cc.
+ */
 
 void
-error_exit_cleanup()
+ddserror(parser_arg *, const string &)
 {
-    delete id; id = 0;
-    delete current; current = 0;
-    delete ctor; ctor = 0;
 }
 
 /*
-  Invalid declaration message.
-*/
+ Error clean up. Call this before calling YYBORT. Don't call this on a
+ normal exit.
+ */
 
-void
-invalid_declaration(parser_arg *arg, string semantic_err_msg, char *type, 
-		    char *name)
+void error_exit_cleanup()
 {
-  ostringstream msg;
-  msg << "In the dataset descriptor object: `" << type << " " << name 
-      << "'" << endl << "is not a valid declaration." << endl 
-      << semantic_err_msg;
-  parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num);
+    delete id;
+    id = 0;
+    delete current;
+    current = 0;
+    delete ctor;
+    ctor = 0;
 }
 
 /*
-  Add the variable pointed to by CURRENT to either the topmost ctor object on
-  the stack CTOR or to the dataset variable table TABLE if CTOR is empty.  If
-  it exists, the current ctor object is popped off the stack and assigned to
-  CURRENT.
+ Invalid declaration message.
+ */
 
-  NB: the ctor stack is popped for arrays because they are ctors which
-  contain only a single variable. For other ctor types, several variables may
-  be members and the parse rule (see `declaration' above) determines when to
-  pop the stack.
+void invalid_declaration(parser_arg *arg, string semantic_err_msg, char *type, char *name)
+{
+    ostringstream msg;
+    msg << "In the dataset descriptor object: `" << type << " " << name << "'" << endl << "is not a valid declaration."
+            << endl << semantic_err_msg;
+    parse_error((parser_arg *) arg, msg.str().c_str(), dds_line_num);
+}
 
-  Returns: void 
-*/
+/*
+ Add the variable pointed to by CURRENT to either the topmost ctor object on
+ the stack CTOR or to the dataset variable table TABLE if CTOR is empty.  If
+ it exists, the current ctor object is popped off the stack and assigned to
+ CURRENT.
 
-void	
-add_entry(DDS &table, stack<BaseType *> **ctor, BaseType **current, Part part)
-{ 
+ NB: the ctor stack is popped for arrays because they are ctors which
+ contain only a single variable. For other ctor types, several variables may
+ be members and the parse rule (see `declaration' above) determines when to
+ pop the stack.
+
+ Returns: void 
+ */
+
+void add_entry(DDS &table, stack<BaseType *> **ctor, BaseType **current, Part part)
+{
     if (!*ctor)
-	*ctor = new stack<BaseType *>;
+        *ctor = new stack<BaseType *> ;
 
     if (!(*ctor)->empty()) { /* must be parsing a ctor type */
-	(*ctor)->top()->add_var(*current, part);
+        (*ctor)->top()->add_var(*current, part);
 
- 	const Type &ctor_type = (*ctor)->top()->type();
+        const Type &ctor_type = (*ctor)->top()->type();
 
-	if (ctor_type == dods_array_c) {
-	    if( *current ) delete *current ;
-	    *current = (*ctor)->top();
-	    (*ctor)->pop();
+        if (ctor_type == dods_array_c) {
+            if (*current)
+                delete *current;
+            *current = (*ctor)->top();
+            (*ctor)->pop();
 
-	    // Return here to avoid deleting the new value of 'current.'
-	    return;
-	}
+            // Return here to avoid deleting the new value of 'current.'
+            return;
+        }
     }
     else {
-	table.add_var(*current);
+        table.add_var(*current);
     }
 
-    if (*current) 
-	delete *current; 
+    if (*current)
+        delete *current;
     *current = 0;
 }
 
