@@ -20,7 +20,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -36,11 +36,6 @@
 // ReZa 9/30/94
 
 #include "config.h"
-#undef FILE_METHODS
-
-static char rcsid[] not_used =
-    {"$Id: mime_util.cc 24370 2011-03-28 16:21:32Z jimg $"
-    };
 
 #include <cstring>
 #include <cstdio>
@@ -159,6 +154,9 @@ string
 rfc822_date(const time_t t)
 {
     struct tm *stm = gmtime(&t);
+    if (!stm)
+    	return "";
+
     char d[256];
 
     snprintf(d, 255, "%s, %02d %s %4d %02d:%02d:%02d GMT", days[stm->tm_wday],
@@ -170,7 +168,7 @@ rfc822_date(const time_t t)
 }
 
 static const int TimLen = 26; // length of string from asctime()
-static const int CLUMP_SIZE = 1024; // size of clumps to new in fmakeword()
+//static const int CLUMP_SIZE = 1024; // size of clumps to new in fmakeword()
 
 /** This sends a formatted block of text to the client, containing
     version information about various aspects of the server.  The
@@ -227,8 +225,17 @@ ErrMsgT(const string &Msgt)
     if (time(&TimBin) == (time_t) - 1)
         strncpy(TimStr, "time() error           ", TimLen-1);
     else {
-        strncpy(TimStr, ctime(&TimBin), TimLen-1);
-        TimStr[TimLen - 2] = '\0'; // overwrite the \n
+    	char *ctime_value = ctime(&TimBin);
+    	if (!ctime_value)
+    		strncpy(TimStr, "Unknown", TimLen-1);
+    	else {
+    		strncpy(TimStr, ctime_value, TimLen-1);
+    		TimStr[TimLen - 2] = '\0'; // overwrite the \n
+    	}
+#if 0
+    	strncpy(TimStr, ctime(&TimBin), TimLen-1);
+    	TimStr[TimLen - 2] = '\0'; // overwrite the \n
+#endif
     }
 
     cerr << "[" << TimStr << "] DAP server error: " << Msgt << endl;
@@ -358,7 +365,6 @@ get_description_type(const string &value)
         return unknown_type;
 }
 
-#if FILE_METHODS
 /** Generate an HTTP 1.0 response header for a text document. This is used
     when returning a serialized DAS or DDS object.
 
@@ -376,43 +382,10 @@ void
 set_mime_text(FILE *out, ObjectType type, const string &ver,
               EncodingType enc, const time_t last_modified)
 {
-    fprintf(out, "HTTP/1.0 200 OK%s", CRLF) ;
-    if (ver == "") {
-        fprintf(out, "XDODS-Server: %s%s", DVR, CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", DVR, CRLF) ;
-    }
-    else {
-        fprintf(out, "XDODS-Server: %s%s", ver.c_str(), CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", ver.c_str(), CRLF) ;
-    }
-    fprintf(out, "XDAP: %s%s", DAP_PROTOCOL_VERSION, CRLF) ;
-
-    const time_t t = time(0);
-    fprintf(out, "Date: %s%s", rfc822_date(t).c_str(), CRLF) ;
-
-    fprintf(out, "Last-Modified: ") ;
-    if (last_modified > 0)
-        fprintf(out, "%s%s", rfc822_date(last_modified).c_str(), CRLF) ;
-    else
-        fprintf(out, "%s%s", rfc822_date(t).c_str(), CRLF) ;
-
-    if (type == dap4_ddx)
-        fprintf(out, "Content-Type: text/xml%s", CRLF) ;
-    else
-        fprintf(out, "Content-Type: text/plain%s", CRLF) ;
-
-    // Note that Content-Description is from RFC 2045 (MIME, pt 1), not 2616.
-    // jhrg 12/23/05
-    fprintf(out, "Content-Description: %s%s", descrip[type], CRLF) ;
-    if (type == dods_error) // don't cache our error responses.
-        fprintf(out, "Cache-Control: no-cache%s", CRLF) ;
-    // Don't write a Content-Encoding header for x-plain since that breaks
-    // Netscape on NT. jhrg 3/23/97
-    if (enc != x_plain)
-        fprintf(out, "Content-Encoding: %s%s", encoding[enc], CRLF) ;
-    fprintf(out, CRLF) ;
+    ostringstream oss;
+    set_mime_text(oss, type, ver, enc, last_modified);
+    fwrite(oss.str().data(), 1, oss.str().length(), out);
 }
-#endif
 
 /** Generate an HTTP 1.0 response header for a text document. This is used
     when returning a serialized DAS or DDS object.
@@ -468,7 +441,60 @@ set_mime_text(ostream &strm, ObjectType type, const string &ver,
     strm << CRLF ;
 }
 
-#if FILE_METHODS
+/** Generate an HTTP 1.0 response header for a text document. This is used
+ when returning a serialized DAS or DDS object.
+
+ @note In Hyrax these headers are not used. Instead the front end of the
+ server will build the response headers
+
+ @param strm Write the MIME header to this stream.
+ @param type The type of this this response. Defaults to
+ application/octet-stream.
+ @param ver The version string; denotes the libdap implementation
+ version.
+ @param enc How is this response encoded? Can be plain or deflate or the
+ x_... versions of those. Default is x_plain.
+ @param last_modified The time to use for the Last-Modified header value.
+ Default is zero which means use the current time. */
+void set_mime_text(ostream &strm, ObjectType type, EncodingType enc, const time_t last_modified,
+        const string &protocol)
+{
+    strm << "HTTP/1.0 200 OK" << CRLF;
+
+    strm << "XDODS-Server: " << DVR<< CRLF;
+    strm << "XOPeNDAP-Server: " << DVR<< CRLF;
+
+    if (protocol == "")
+        strm << "XDAP: " << DAP_PROTOCOL_VERSION << CRLF;
+    else
+        strm << "XDAP: " << protocol << CRLF;
+
+    const time_t t = time(0);
+    strm << "Date: " << rfc822_date(t).c_str() << CRLF;
+
+    strm << "Last-Modified: ";
+    if (last_modified > 0)
+        strm << rfc822_date(last_modified).c_str() << CRLF;
+    else
+        strm << rfc822_date(t).c_str() << CRLF;
+
+    if (type == dap4_ddx)
+        strm << "Content-Type: text/xml" << CRLF;
+    else
+        strm << "Content-Type: text/plain" << CRLF;
+
+    // Note that Content-Description is from RFC 2045 (MIME, pt 1), not 2616.
+    // jhrg 12/23/05
+    strm << "Content-Description: " << descrip[type] << CRLF;
+    if (type == dods_error) // don't cache our error responses.
+        strm << "Cache-Control: no-cache" << CRLF;
+    // Don't write a Content-Encoding header for x-plain since that breaks
+    // Netscape on NT. jhrg 3/23/97
+    if (enc != x_plain)
+        strm << "Content-Encoding: " << encoding[enc] << CRLF;
+    strm << CRLF;
+}
+
 /** Generate an HTTP 1.0 response header for a html document.
 
     @deprecated
@@ -484,38 +510,10 @@ void
 set_mime_html(FILE *out, ObjectType type, const string &ver,
               EncodingType enc, const time_t last_modified)
 {
-    fprintf(out, "HTTP/1.0 200 OK%s", CRLF) ;
-    if (ver == "") {
-        fprintf(out, "XDODS-Server: %s%s", DVR, CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", DVR, CRLF) ;
-    }
-    else {
-        fprintf(out, "XDODS-Server: %s%s", ver.c_str(), CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", ver.c_str(), CRLF) ;
-    }
-    fprintf(out, "XDAP: %s%s", DAP_PROTOCOL_VERSION, CRLF) ;
-
-    const time_t t = time(0);
-    fprintf(out, "Date: %s%s", rfc822_date(t).c_str(), CRLF) ;
-
-    fprintf(out, "Last-Modified: ") ;
-    if (last_modified > 0)
-        fprintf(out, "%s%s", rfc822_date(last_modified).c_str(), CRLF) ;
-    else
-        fprintf(out, "%s%s", rfc822_date(t).c_str(), CRLF) ;
-
-    fprintf(out, "Content-type: text/html%s", CRLF) ;
-    // See note above about Content-Description header. jhrg 12/23/05
-    fprintf(out, "Content-Description: %s%s", descrip[type], CRLF) ;
-    if (type == dods_error) // don't cache our error responses.
-        fprintf(out, "Cache-Control: no-cache%s", CRLF) ;
-    // Don't write a Content-Encoding header for x-plain since that breaks
-    // Netscape on NT. jhrg 3/23/97
-    if (enc != x_plain)
-        fprintf(out, "Content-Encoding: %s%s", encoding[enc], CRLF) ;
-    fprintf(out, CRLF) ;
+    ostringstream oss;
+    set_mime_html(oss, type, ver, enc, last_modified);
+    fwrite(oss.str().data(), 1, oss.str().length(), out);
 }
-#endif
 
 /** Generate an HTTP 1.0 response header for a html document.
 
@@ -564,7 +562,50 @@ set_mime_html(ostream &strm, ObjectType type, const string &ver,
     strm << CRLF ;
 }
 
-#if FILE_METHODS
+/** Generate an HTTP 1.0 response header for a html document.
+
+ @param strm Write the MIME header to this stream.
+ @param type The type of this this response.
+ @param ver The version string; denotes the libdap implementation
+ version.
+ @param enc How is this response encoded? Can be plain or deflate or the
+ x_... versions of those. Default is x_plain.
+ @param last_modified The time to use for the Last-Modified header value.
+ Default is zero which means use the current time. */
+void set_mime_html(ostream &strm, ObjectType type, EncodingType enc, const time_t last_modified,
+        const string &protocol)
+{
+    strm << "HTTP/1.0 200 OK" << CRLF;
+
+    strm << "XDODS-Server: " << DVR<< CRLF;
+    strm << "XOPeNDAP-Server: " << DVR<< CRLF;
+
+    if (protocol == "")
+        strm << "XDAP: " << DAP_PROTOCOL_VERSION << CRLF;
+    else
+        strm << "XDAP: " << protocol << CRLF;
+
+    const time_t t = time(0);
+    strm << "Date: " << rfc822_date(t).c_str() << CRLF;
+
+    strm << "Last-Modified: ";
+    if (last_modified > 0)
+        strm << rfc822_date(last_modified).c_str() << CRLF;
+    else
+        strm << rfc822_date(t).c_str() << CRLF;
+
+    strm << "Content-type: text/html" << CRLF;
+    // See note above about Content-Description header. jhrg 12/23/05
+    strm << "Content-Description: " << descrip[type] << CRLF;
+    if (type == dods_error) // don't cache our error responses.
+        strm << "Cache-Control: no-cache" << CRLF;
+    // Don't write a Content-Encoding header for x-plain since that breaks
+    // Netscape on NT. jhrg 3/23/97
+    if (enc != x_plain)
+        strm << "Content-Encoding: " << encoding[enc] << CRLF;
+    strm << CRLF;
+}
+
 /** Write an HTTP 1.0 response header for our binary response document (i.e.,
     the DataDDS object).
 
@@ -583,34 +624,10 @@ void
 set_mime_binary(FILE *out, ObjectType type, const string &ver,
                 EncodingType enc, const time_t last_modified)
 {
-    fprintf(out, "HTTP/1.0 200 OK%s", CRLF) ;
-    if (ver == "") {
-        fprintf(out, "XDODS-Server: %s%s", DVR, CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", DVR, CRLF) ;
-    }
-    else {
-        fprintf(out, "XDODS-Server: %s%s", ver.c_str(), CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", ver.c_str(), CRLF) ;
-    }
-    fprintf(out, "XDAP: %s%s", DAP_PROTOCOL_VERSION, CRLF) ;
-
-    const time_t t = time(0);
-    fprintf(out, "Date: %s%s", rfc822_date(t).c_str(), CRLF) ;
-
-    fprintf(out, "Last-Modified: ") ;
-    if (last_modified > 0)
-        fprintf(out, "%s%s", rfc822_date(last_modified).c_str(), CRLF) ;
-    else
-        fprintf(out, "%s%s", rfc822_date(t).c_str(), CRLF) ;
-
-    fprintf(out, "Content-Type: application/octet-stream%s", CRLF) ;
-    fprintf(out, "Content-Description: %s%s", descrip[type], CRLF) ;
-    if (enc != x_plain)
-        fprintf(out, "Content-Encoding: %s%s", encoding[enc], CRLF) ;
-
-    fprintf(out, CRLF) ;
+    ostringstream oss;
+    set_mime_binary(oss, type, ver, enc, last_modified);
+    fwrite(oss.str().data(), 1, oss.str().length(), out);
 }
-#endif
 
 /** Write an HTTP 1.0 response header for our binary response document (i.e.,
     the DataDDS object).
@@ -658,6 +675,49 @@ set_mime_binary(ostream &strm, ObjectType type, const string &ver,
     strm << CRLF ;
 }
 
+/** Write an HTTP 1.0 response header for our binary response document (i.e.,
+ the DataDDS object).
+
+ @param strm Write the MIME header to this stream.
+ @param type The type of this this response. Defaults to
+ application/octet-stream.
+ @param ver The version string; denotes the libdap implementation
+ version.
+ @param enc How is this response encoded? Can be plain or deflate or the
+ x_... versions of those. Default is x_plain.
+ @param last_modified The time to use for the Last-Modified header value.
+ Default is zero which means use the current time.
+ */
+void set_mime_binary(ostream &strm, ObjectType type, EncodingType enc, const time_t last_modified,
+        const string &protocol)
+{
+    strm << "HTTP/1.0 200 OK" << CRLF;
+
+    strm << "XDODS-Server: " << DVR << CRLF;
+    strm << "XOPeNDAP-Server: " << DVR << CRLF;
+
+    if (protocol == "")
+        strm << "XDAP: " << DAP_PROTOCOL_VERSION << CRLF;
+    else
+        strm << "XDAP: " << protocol << CRLF;
+
+    const time_t t = time(0);
+    strm << "Date: " << rfc822_date(t).c_str() << CRLF;
+
+    strm << "Last-Modified: ";
+    if (last_modified > 0)
+        strm << rfc822_date(last_modified).c_str() << CRLF;
+    else
+        strm << rfc822_date(t).c_str() << CRLF;
+
+    strm << "Content-Type: application/octet-stream" << CRLF;
+    strm << "Content-Description: " << descrip[type] << CRLF;
+    if (enc != x_plain)
+        strm << "Content-Encoding: " << encoding[enc] << CRLF;
+
+    strm << CRLF;
+}
+
 void set_mime_multipart(ostream &strm, const string &boundary,
 	const string &start, ObjectType type,
         const string &version, EncodingType enc,
@@ -692,6 +752,46 @@ void set_mime_multipart(ostream &strm, const string &boundary,
     strm << CRLF ;
 }
 
+/** Build the initial headers for the DAP4 data response */
+
+void set_mime_multipart(ostream &strm, const string &boundary, const string &start, ObjectType type, EncodingType enc,
+        const time_t last_modified, const string &protocol, const string &url)
+{
+    strm << "HTTP/1.1 200 OK" << CRLF;
+
+    const time_t t = time(0);
+    strm << "Date: " << rfc822_date(t).c_str() << CRLF;
+
+    strm << "Last-Modified: ";
+    if (last_modified > 0)
+        strm << rfc822_date(last_modified).c_str() << CRLF;
+    else
+        strm << rfc822_date(t).c_str() << CRLF;
+
+    strm << "Content-Type: multipart/related; boundary=" << boundary << "; start=\"<" << start
+            << ">\"; type=\"text/xml\"" << CRLF;
+
+    // data-ddx;"; removed as a result of the merge of the hyrax 1.8 release
+    // branch.
+    strm << "Content-Description: " << descrip[type] << ";";
+    if (!url.empty())
+        strm << " url=\"" << url << "\"" << CRLF;
+    else
+        strm << CRLF;
+
+    if (enc != x_plain)
+        strm << "Content-Encoding: " << encoding[enc] << CRLF;
+
+    if (protocol == "")
+        strm << "X-DAP: " << DAP_PROTOCOL_VERSION << CRLF;
+    else
+        strm << "X-DAP: " << protocol << CRLF;
+
+    strm << "X-OPeNDAP-Server: " << DVR<< CRLF;
+
+    strm << CRLF;
+}
+
 void set_mime_ddx_boundary(ostream &strm, const string &boundary,
 	const string &cid, ObjectType type, EncodingType enc)
 {
@@ -723,7 +823,7 @@ const size_t line_length = 1024;
 /** Read the next MIME header from the input stream and return it in a string
     object. This function consumes any leading whitespace before the next
     header. It returns an empty string when the blank line that separates
-    the headers from the body is found. this function works for header and
+    the headers from the body is found. This function works for header and
     separator lines that use either a CRLF pair (the correct line ending) or
     just a newline (a common error).
 
@@ -755,6 +855,40 @@ string get_next_mime_header(FILE *in)
     throw Error("I expected to find a MIME header, but got EOF instead.");
 }
 
+string get_next_mime_header(istream &in)
+{
+#if 0
+    // Get the header line and strip \r\n. Some headers end with just \n.
+    // If a blank line is found, return an empty string.
+	char line[line_length];
+	while (!in.eof()) {
+		in.getline(line, line_length);
+		if (strncmp(line, CRLF, 2) == 0 || line[0] == '\n') {
+			return "";
+		}
+		else {
+			size_t slen = min(strlen(line), line_length); // Never > line_length
+			line[slen - 1] = '\0'; // remove the newline
+			if (line[slen - 2] == '\r') // ...and the preceding carriage return
+				line[slen - 2] = '\0';
+			return string(line);
+		}
+	}
+#endif
+    // Get the header line and strip \r\n. Some headers end with just \n.
+    // If a blank line is found, return an empty string.
+	char raw_line[line_length];
+	while (!in.eof()) {
+		in.getline(raw_line, line_length); // strips the trailing newline; terminates with null
+		string line = raw_line;
+		if (line.find('\r') != string::npos)
+			line = line.substr(0, line.size()-1);
+		return line;
+	}
+
+	throw Error("I expected to find a MIME header, but got EOF instead.");
+}
+
 /** Given a string that contains a MIME header line, parse it into the
     the header (name) and its value. Both are downcased.
 
@@ -821,13 +955,27 @@ string read_multipart_boundary(FILE *in, const string &boundary)
     return boundary_line;
 }
 
+string read_multipart_boundary(istream &in, const string &boundary)
+{
+    string boundary_line = get_next_mime_header(in);
+    // If the caller passed in a value for the boundary, test for that value,
+    // else just see that this line starts with '--'.
+    // The value of 'boundary_line' is returned by this function.
+    if ((!boundary.empty() && is_boundary(boundary_line.c_str(), boundary))
+	    || boundary_line.find("--") != 0)
+	throw Error(
+		"The DAP4 data response document is broken - missing or malformed boundary.");
+
+    return boundary_line;
+}
+
 /** Consume the Multipart MIME headers that prefix the DDX in a DataDDX
     response. The stream pointer is advanced to the start of the DDX. It might
     seem odd that this function both takes the value of the MPM boundary as
     a parameter _and_ returns that value as a result, but this code can be
     used in two different situations. In one case, it is called on a partial
     document read from stdin and needs to return the value of boundary to the
-    downstream DDX parser to that code can sense the end of hte DDX. In the
+    downstream DDX parser so that code can sense the end of the DDX. In the
     other case, this function is told the value of boundary and tests for it
     to ensure document correctness.
 
@@ -841,39 +989,70 @@ string read_multipart_boundary(FILE *in, const string &boundary)
     header values don't match. The optional values are tested only if they
     are given (the default values are not tested).
  */
-void read_multipart_headers(FILE *in, const string &content_type,
-	const ObjectType object_type, const string &cid)
+void read_multipart_headers(FILE *in, const string &content_type, const ObjectType object_type, const string &cid)
 {
-    bool ct = false, cd = false, ci = false;
+	bool ct = false, cd = false, ci = false;
 
-    string header = get_next_mime_header(in);
-    while (!header.empty()) {
-	string name, value;
-	parse_mime_header(header, name, value);
+	string header = get_next_mime_header(in);
+	while (!header.empty()) {
+		string name, value;
+		parse_mime_header(header, name, value);
 
-	if (name =="content-type") {
-	    ct = true;
-	    if (value.find(content_type) == string::npos)
-		throw Error("Content-Type for this part of a DAP4 data response must be " + content_type + ".");
-	}
-	else if (name == "content-description") {
-	    cd = true;
-	    if (get_description_type(value) != object_type)
-		throw Error("Content-Description for this part of a DAP4 data response must be dap4-ddx or dap4-data-ddx");
-	}
-	else if (name == "content-id") {
-	    ci = true;
-	    if (!cid.empty() && value != cid)
-		throw Error("Content-Id mismatch. Expected: " + cid
-			+ ", but got: " + value);
+		if (name == "content-type") {
+			ct = true;
+			if (value.find(content_type) == string::npos)
+				throw Error("Content-Type for this part of a DAP4 data response must be " + content_type + ".");
+		}
+		else if (name == "content-description") {
+			cd = true;
+			if (get_description_type(value) != object_type)
+				throw Error(
+						"Content-Description for this part of a DAP4 data response must be dap4-ddx or dap4-data-ddx");
+		}
+		else if (name == "content-id") {
+			ci = true;
+			if (!cid.empty() && value != cid)
+				throw Error("Content-Id mismatch. Expected: " + cid + ", but got: " + value);
+		}
+
+		header = get_next_mime_header(in);
 	}
 
-	header = get_next_mime_header(in);
-    }
-
-    if (!(ct && cd && ci))
-	throw Error("The DAP4 data response document is broken - missing header.");
+	if (!(ct && cd && ci)) throw Error("The DAP4 data response document is broken - missing header.");
 }
+
+void read_multipart_headers(istream &in, const string &content_type, const ObjectType object_type, const string &cid)
+{
+	bool ct = false, cd = false, ci = false;
+
+	string header = get_next_mime_header(in);
+	while (!header.empty()) {
+		string name, value;
+		parse_mime_header(header, name, value);
+
+		if (name == "content-type") {
+			ct = true;
+			if (value.find(content_type) == string::npos)
+				throw Error("Content-Type for this part of a DAP4 data response must be " + content_type + ".");
+		}
+		else if (name == "content-description") {
+			cd = true;
+			if (get_description_type(value) != object_type)
+				throw Error(
+						"Content-Description for this part of a DAP4 data response must be dap4-ddx or dap4-data-ddx");
+		}
+		else if (name == "content-id") {
+			ci = true;
+			if (!cid.empty() && value != cid)
+				throw Error("Content-Id mismatch. Expected: " + cid + ", but got: " + value);
+		}
+
+		header = get_next_mime_header(in);
+	}
+
+	if (!(ct && cd && ci)) throw Error("The DAP4 data response document is broken - missing header.");
+}
+
 /** Given a Content-Id read from the DDX, return the value to look for in a
     MPM Content-Id header. This function downcases the CID to match the value
     returned by parse_mime_header.
@@ -886,7 +1065,7 @@ string cid_to_header_value(const string &cid)
 {
     string::size_type offset = cid.find("cid:");
     if (offset != 0)
-	throw Error("expected CID to start with 'cid:'");
+        throw Error("expected CID to start with 'cid:'");
 
     string value = "<";
     value.append(cid.substr(offset + 4));
@@ -896,7 +1075,6 @@ string cid_to_header_value(const string &cid)
     return value;
 }
 
-#if FILE_METHODS
 /** Generate an HTTP 1.0 response header for an Error object.
 
     @deprecated
@@ -909,23 +1087,10 @@ void
 set_mime_error(FILE *out, int code, const string &reason,
                const string &version)
 {
-    fprintf(out, "HTTP/1.0 %d %s%s", code, reason.c_str(), CRLF) ;
-    if (version == "") {
-        fprintf(out, "XDODS-Server: %s%s", DVR, CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", DVR, CRLF) ;
-    }
-    else {
-        fprintf(out, "XDODS-Server: %s%s", version.c_str(), CRLF) ;
-        fprintf(out, "XOPeNDAP-Server: %s%s", version.c_str(), CRLF) ;
-    }
-    fprintf(out, "XDAP: %s%s", DAP_PROTOCOL_VERSION, CRLF) ;
-
-    const time_t t = time(0);
-    fprintf(out, "Date: %s%s", rfc822_date(t).c_str(), CRLF) ;
-    fprintf(out, "Cache-Control: no-cache%s", CRLF) ;
-    fprintf(out, CRLF) ;
+    ostringstream oss;
+    set_mime_error(oss, code, reason, version);
+    fwrite(oss.str().data(), 1, oss.str().length(), out);
 }
-#endif
 
 /** Generate an HTTP 1.0 response header for an Error object.
 
@@ -956,7 +1121,6 @@ set_mime_error(ostream &strm, int code, const string &reason,
     strm << CRLF ;
 }
 
-#if FILE_METHODS
 /** Use this function to create a response signaling that the target of a
     conditional get has not been modified relative to the condition given in
     the request. This will have to be a date until the servers support ETags.
@@ -967,12 +1131,10 @@ set_mime_error(ostream &strm, int code, const string &reason,
 void
 set_mime_not_modified(FILE *out)
 {
-    fprintf(out, "HTTP/1.0 304 NOT MODIFIED%s", CRLF) ;
-    const time_t t = time(0);
-    fprintf(out, "Date: %s%s", rfc822_date(t).c_str(), CRLF) ;
-    fprintf(out, CRLF) ;
+    ostringstream oss;
+    set_mime_not_modified(oss);
+    fwrite(oss.str().data(), 1, oss.str().length(), out);
 }
-#endif
 
 /** Use this function to create a response signaling that the target of a
     conditional get has not been modified relative to the condition given in
@@ -990,6 +1152,10 @@ set_mime_not_modified(ostream &strm)
     strm << CRLF ;
 }
 
+#if 0
+
+// This was removed because it's not being used by our server.
+
 /** Look for the override file by taking the dataset name and
     appending `.ovr' to it. If such a file exists, then read it in and
     store the contents in <tt>doc</tt>. Note that the file contents
@@ -1010,13 +1176,15 @@ found_override(string name, string &doc)
     doc = "";
     while (!ifs.eof()) {
         ifs.getline(tmp, 255);
-        strcat(tmp, "\n");
+        tmp[255] = '\0';
+        strncat(tmp, "\n", sizeof(tmp) - strlen(tmp) - 1);
         doc += tmp;
     }
 
 	ifs.close();
     return true;
 }
+#endif
 
 /** Read the input stream <tt>in</tt> and discard the MIME header. The MIME
     header is separated from the body of the document by a single blank line.
