@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -73,17 +73,29 @@ time_t last_modified_time(const string &name);
 ObjectType get_description_type(const string &value);
 bool is_boundary(const char *line, const string &boundary);
 string cid_to_header_value(const string &cid);
-string read_multipart_boundary(FILE *in, const string &boundary = "");
+
+string read_multipart_boundary(istream &in, const string &boundary = "");
+
 void parse_mime_header(const string &header, string &name, string &value);
 string name_path(const string &path);
+string get_next_mime_header(istream &in);
+
+void read_multipart_headers(istream &in, const string &content_type,
+	const ObjectType object_type, const string &cid = "");
 
 // All of these are deprecated
+string read_multipart_boundary(FILE *in, const string &boundary = "");
+void read_multipart_headers(FILE *in, const string &content_type,
+	const ObjectType object_type, const string &cid = "");
 bool do_version(const string &script_ver, const string &dataset_ver);
 void ErrMsgT(const string &Msgt);
-ObjectType get_type(const string &value); // deprecated
+ObjectType get_type(const string &value);
 bool remove_mime_header(FILE *in);
 string get_next_mime_header(FILE *in);
+
+#if 0
 bool found_override(string name, string &doc);
+#endif
 //@}
 
 /** These functions are used to create the MIME headers for a message
@@ -104,6 +116,10 @@ void set_mime_text(FILE *out, ObjectType type = unknown_type,
 void set_mime_text(ostream &out, ObjectType type = unknown_type,
                    const string &version = "", EncodingType enc = x_plain,
                    const time_t last_modified = 0);
+void set_mime_text(std::ostream &out, ObjectType type = unknown_type,
+                   EncodingType enc = x_plain,
+                   const time_t last_modified = 0,
+                   const std::string &protocol = "");
 
 void set_mime_html(FILE *out, ObjectType type = unknown_type,
                    const string &version = "", EncodingType enc = x_plain,
@@ -111,6 +127,10 @@ void set_mime_html(FILE *out, ObjectType type = unknown_type,
 void set_mime_html(ostream &out, ObjectType type = unknown_type,
                    const string &version = "", EncodingType enc = x_plain,
                    const time_t last_modified = 0);
+void set_mime_html(std::ostream &out, ObjectType type = unknown_type,
+                   EncodingType enc = x_plain,
+                   const time_t last_modified = 0,
+                   const std::string &protocol = "");
 
 void set_mime_binary(FILE *out, ObjectType type = unknown_type,
                      const string &version = "", EncodingType enc = x_plain,
@@ -118,12 +138,21 @@ void set_mime_binary(FILE *out, ObjectType type = unknown_type,
 void set_mime_binary(ostream &out, ObjectType type = unknown_type,
                      const string &version = "", EncodingType enc = x_plain,
                      const time_t last_modified = 0);
+void set_mime_binary(std::ostream &out, ObjectType type = unknown_type,
+                     EncodingType enc = x_plain,
+                     const time_t last_modified = 0,
+                     const std::string &protocol = "");
 
 void set_mime_multipart(ostream &out, const string &boundary,
 	const string &start, ObjectType type = unknown_type,
         const string &version = "", EncodingType enc = x_plain,
         const time_t last_modified = 0);
 
+void set_mime_multipart(std::ostream &out, const std::string &boundary,
+	const std::string &start, ObjectType type = unknown_type, EncodingType enc = x_plain,
+	const time_t last_modified = 0, const std::string &protocol = "",
+	const std::string &url = "");
+
 void set_mime_ddx_boundary(ostream &out, const string &boundary,
 	const string &start, ObjectType type = unknown_type,
         EncodingType enc = x_plain);
@@ -132,9 +161,6 @@ void set_mime_data_boundary(ostream &out, const string &boundary,
 	const string &cid, ObjectType type = unknown_type,
         EncodingType enc = x_plain);
 
-void read_multipart_headers(FILE *in, const string &content_type,
-	const ObjectType object_type, const string &cid = "");
-
 void set_mime_error(FILE *out, int code = 404,
                     const string &reason = "Dataset not found",
                     const string &version = "");
