@@ -19,7 +19,7 @@
 // 
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
  
@@ -130,20 +130,17 @@ TestGrid::~TestGrid()
 {
 }
 
-bool
-TestGrid::read()
+bool TestGrid::read()
 {
     if (read_p())
-	return true;
+        return true;
 
     get_array()->read();
 
-    for (Map_iter i = map_begin(); i != map_end(); i++)
-    {
-	if (!(*i)->read())
-	{
-	    return false;
-	}
+    for (Map_iter i = map_begin(); i != map_end(); i++) {
+        if (!(*i)->read()) {
+            return false;
+        }
     }
 
     set_read_p(true);
