@@ -19,7 +19,7 @@
 // 
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
  
@@ -56,13 +56,13 @@ TestInt16::_duplicate(const TestInt16 &ts)
 
 TestInt16::TestInt16(const string &n) : Int16(n), d_series_values(false)
 {
-    _buf = 1;
+    d_buf = 1;
 }
 
 TestInt16::TestInt16(const string &n, const string &d)
     : Int16(n, d), d_series_values(false)
 {
-    _buf = 1;
+    d_buf = 1;
 }
 
 TestInt16::TestInt16(const TestInt16 &rhs) : Int16(rhs), TestCommon(rhs)
@@ -106,10 +106,10 @@ TestInt16::read()
 	sleep(test_variable_sleep_interval);
 
     if (get_series_values()) {
-       _buf = (short)(16 * _buf);
+       d_buf = (short)(16 * d_buf);
     }
     else {
-        _buf = 32000;
+        d_buf = 32000;
     }
 
     set_read_p(true);
