@@ -19,7 +19,7 @@
 // 
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
  
@@ -57,13 +57,13 @@ TestUInt32::_duplicate(const TestUInt32 &ts)
 
 TestUInt32::TestUInt32(const string &n) : UInt32(n), d_series_values(false)
 {
-    _buf = 1;
+    d_buf = 1;
 }
 
 TestUInt32::TestUInt32(const string &n, const string &d)
     : UInt32(n, d), d_series_values(false)
 {
-    _buf = 1;
+    d_buf = 1;
 }
 
 TestUInt32::TestUInt32(const TestUInt32 &rhs) : UInt32(rhs), TestCommon(rhs)
@@ -107,10 +107,10 @@ TestUInt32::read()
 	sleep(test_variable_sleep_interval);
 
     if (get_series_values()) {
-        _buf = 32 * _buf;
+        d_buf = 32 * d_buf;
     }
     else {
-        _buf = 0xf0000000;		// about 4 billion
+        d_buf = 0xf0000000;		// about 4 billion
     }
 
     set_read_p(true);
