@@ -19,7 +19,7 @@
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
@@ -35,20 +35,16 @@
 
 #include "config.h"
 
-#define DODS_DEBUG
-
-static char rcsid[] not_used =
-    { "$Id: expr-test.cc 24082 2011-02-08 18:44:27Z jimg $" };
+//#define DODS_DEBUG
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifndef WIN32
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <string.h>
 #include <errno.h>
 
-
 #include <iostream>
 #include <fstream>
 #include <string>
@@ -59,12 +55,8 @@ static char rcsid[] not_used =
 #include "DDS.h"
 #include "DataDDS.h"
 #include "ConstraintEvaluator.h"
-#include "XDRFileUnMarshaller.h"
 #include "XDRStreamUnMarshaller.h"
 #include "XDRStreamMarshaller.h"
-#if 0
-#include "DODSFilter.h"
-#endif
 #include "ResponseBuilder.h"
 #include "Response.h"
 #include "Connect.h"
@@ -104,7 +96,7 @@ void intern_data_test(const string & dds_name, const bool constraint_expr,
                  const string & ce, const bool series_values);
 
 int ce_exprlex();               // exprlex() uses the global ce_exprlval
-int ce_exprparse(void *arg);
+// int ce_exprparse(void *arg);
 void ce_exprrestart(FILE * in);
 
 // Glue routines declared in expr.lex
@@ -114,7 +106,9 @@ void *ce_expr_string(const char *yy_str);
 
 extern int ce_exprdebug;
 
+#if 0
 static int keep_temps = 0;      // MT-safe; test code.
+#endif
 
 const string version = "version 1.12";
 const string prompt = "expr-test: ";
@@ -277,7 +271,6 @@ int main(int argc, char *argv[])
 
 // Instead of reading the tokens from stdin, read them from a string.
 
-
 void test_scanner(const string & str)
 {
     ce_exprrestart(0);
@@ -324,8 +317,8 @@ void test_scanner(bool show_prompt)
         case SCAN_REGEXP:
             cout << "REGEXP: " << ce_exprlval.op << endl;
             break;
-        case '*':
-            cout << "Dereference" << endl;
+        case SCAN_STAR:
+            cout << "STAR: " << ce_exprlval.op << endl;
             break;
         case '.':
             cout << "Field Selector" << endl;
@@ -357,8 +350,12 @@ void test_scanner(bool show_prompt)
         case '&':
             cout << "Ampersand" << endl;
             break;
+        case SCAN_HASH_INT32:
+            cout << "Hash Int32" << endl;
+            break;
         default:
             cout << "Error: Unrecognized input" << endl;
+            break;
         }
 
         cout << prompt << flush;  // print prompt after output
@@ -511,37 +508,22 @@ constrained_trans(const string & dds_name, const bool constraint_expr,
     ResponseBuilder df;
     df.set_ce(ce);
     df.set_dataset_name(dds_name);
-    // df.set_URL("test://test");
-    // df.set_response("DataDDS");
 
     ofstream out("expr-test-data.bin", ios::out|ios::trunc|ios::binary);
-#if 0
-    df.send_data(server, eval, out, "", false);
-#endif
     df.send_data(out, server, eval, true);
-    //cout << "Server protocol version: " << server.get_dap_major() << "." << server.get_dap_minor() << endl;
     out.close();
 
     // Now do what Connect::request_data() does:
     FILE *fp = fopen("expr-test-data.bin", "r");
 
     Response r(fp, 400);
-#if 0
-    r.set_type(dods_data);
-    r.set_protocol("3.2");
-#endif
     Connect c("http://dummy_argument");
 
     BaseTypeFactory factory;
     DataDDS dds(&factory, "Test_data", "DAP/3.2");      // Must use DataDDS on receiving end
 
-#if 0
-    c.read_data_no_mime(dds, &r);
-#endif
     c.read_data(dds, &r);
 
-    //cout << "Protocol version: " << dds.get_protocol() << endl;
-
     cout << "The data:" << endl;
     for (DDS::Vars_iter q = dds.var_begin(); q != dds.var_end(); q++) {
         (*q)->print_val(cout);
@@ -595,19 +577,6 @@ intern_data_test(const string & dds_name, const bool constraint_expr,
 
     server.tag_nested_sequences();      // Tag Sequences as Parent or Leaf node.
 
-#if 0
-    if (eval.functional_expression()) {
-        BaseType *var = eval.eval_function(server, dds_name);
-        if (!var)
-            throw Error(unknown_error, "Error calling the CE function.");
-
-        var->intern_data(eval, server);
-
-        var->set_send_p(true);
-        server.add_var(var);
-    }
-#endif
-
     if (eval.function_clauses()) {
         DDS *fdds = eval.eval_function_clauses(server);
 
